@@ -1,4 +1,6 @@
 #
+# * PROPOSAL
+# *
 # * @contact
 # *
 # * Not built.
@@ -9,9 +11,8 @@
 # Was at http://www.atcontactcom.com/
 #
 # this script for SaVi by Lloyd Wood (lloydwood@users.sourceforge.net)
-# http://personal.ee.surrey.ac.uk/Personal/L.Wood/software/SaVi/
 #
-# $Id: atcontact.tcl,v 1.11 2015/08/31 01:29:33 lloydwood Exp $
+# $Id: atcontact.tcl 170 2020-04-28 03:34:51Z lloydwood $
 
 # site says 16 operational satellites and four spares, one per plane.
 set SATS_PER_PLANE 4
@@ -41,7 +42,8 @@ for {set j 0} {$j < $NUM_PLANES} {incr j} {
 		# we use second harmonic as that appears to give best coverage
 		# with dual or better coverage below 50 degrees of latitude.
 		set T [expr $T_per * $i / $SATS_PER_PLANE - $plane_offset*2*$j]
-		satellites LOAD $a $e $inc $Omega $omega $T "@contact ($j, $i)"
+		set n [satellites LOAD $a $e $inc $Omega $omega $T "@contact ($j, $i)"]
+		if {$i > 0} {satellites ORBIT_SET $n 0}
 	}
 }
 satellites GV_END
