@@ -1,5 +1,5 @@
 #
-# * PROPOSED LARGE BROADBAND CONSTELLATIONS - FAT PIPE DREAMS
+# * 1990s LARGE BROADBAND PROPOSALS - FAT PIPE DREAMS
 # * 
 # * Celestri
 # *
@@ -14,7 +14,7 @@
 # * information used from the Motorola FCC application, June 1997.
 #
 # Was available online in Adobe Acrobat pdf format from Motorola; see:
-# http://personal.ee.surrey.ac.uk/Personal/L.Wood/constellations/celestri/
+# http://lloydwood.users.sourceforge.net/Personal/L.Wood/constellations/celestri/
 # for an archived copy.
 #
 # Full details are in the scanned pdf of the section titled part two,
@@ -22,9 +22,8 @@
 # map showing subsatellite points.
 #
 # this script for SaVi by Lloyd Wood (lloydwood@users.sourceforge.net)
-# http://personal.ee.surrey.ac.uk/Personal/L.Wood/software/SaVi/
 #
-# $Id: celestri.tcl,v 1.13 2015/08/31 01:29:33 lloydwood Exp $
+# $Id: celestri.tcl 116 2019-09-30 07:20:51Z lloydwood $
 
 set SATS_PER_PLANE 9
 set NUM_PLANES 7
@@ -62,7 +61,8 @@ for {set j 0} {$j < $NUM_PLANES} {incr j} {
    for {set i 0} {$i < $SATS_PER_PLANE} {incr i} {
 
        set T [expr ($T_per * $i / $SATS_PER_PLANE) - $plane_offset ]
-       satellites LOAD $a $e $inc $Omega $omega $T "Celestri ($j, $i)"
+       set n [satellites LOAD $a $e $inc $Omega $omega $T "Celestri ($j, $i)"]
+       if {$i > 0} {satellites ORBIT_SET $n 0}
    }
 }
 
