@@ -1,11 +1,11 @@
 #
-# * THEORETICAL CONSTELLATIONS
+# * GEOSYNCHRONOUS CONSTELLATIONS
 # *
 # * Clarke three-satellite geostationary constellation
 # *
 # * Clarke proposed three geostationary satellites spaced 120 deg at:
 # *   30E - Africa and Europe
-# *  150E - China and Oceana
+# *  150E - China and Oceania
 # *   90W - the Americas
 # *
 # * In practice, Inmarsat's BGAN (Broadband Global Area Network) comes
@@ -20,12 +20,12 @@
 # * Arthur C. Clarke, 'Extra-Terrestrial Relays'
 # * pp 305-308, Wireless World, October 1945.
 #
-# http://www.sciencemuseum.org.uk/on-line/clarke/ww1.asp
+# https://web.archive.org/web/20090318000548/http://www.clarkefoundation.org/docs/ClarkeWirelessWorldArticle.pdf
+# https://web.archive.org/web/20070209201445/http://www.sciencemuseum.org.uk:80/on-line/clarke/ww1.asp
 #
 # this script for SaVi by Lloyd Wood (lloydwood@users.sourceforge.net)
-# http://personal.ee.surrey.ac.uk/Personal/L.Wood/software/SaVi/
 #
-# $Id: clarke.tcl,v 1.12 2015/08/31 01:29:33 lloydwood Exp $
+# $Id: clarke.tcl 197 2023-04-11 03:02:04Z lloydwood $
 
 # It's easiest to give each satellite its own RAAN, so we'll treat them
 # as having separate planes even though they're not actually ascending.
@@ -36,7 +36,20 @@ set NUM_PLANES 3
 set sat_longitude 150
 
 # setup orbital elements
-set a [expr 35786.1+$RADIUS_OF_EARTH]
+
+# Earth-centric hack
+# set a [expr 35786.1+$RADIUS_OF_EARTH]
+
+# match the current stationary altitude.
+# see tcl/equator.tcl for working
+set OM $params(Omega)
+
+set cuberoot [expr 1.0/3]
+set a [expr { 0.0 + pow(($MU / $OM / $OM), $cuberoot) } ]
+
+set radius [format "%0.2f" $a]
+puts stderr "\nSaVi: stationary radius is $radius km."
+
 set e 0.0
 set inc 0.0
 set omega 0.0
