@@ -1,4 +1,6 @@
 #
+# * PROPOSAL
+# *
 # * GS-2 (Globalstar proposal)
 # *
 # * Intended for voice and data in S-band.
@@ -8,11 +10,12 @@
 # *
 # * Uses intersatellite links, which are not yet simulated here.
 # * The filing also mentions four geostationary satellites, not simulated.
+# * Second-generation Globalstar satellites turned out rather
+# * differently.
 #
 # this script for SaVi by Lloyd Wood (lloydwood@users.sourceforge.net)
-# http://personal.ee.surrey.ac.uk/Personal/L.Wood/software/SaVi/
 #
-# $Id: gs2.tcl,v 1.11 2015/08/31 01:29:33 lloydwood Exp $
+# $Id: gs2.tcl 170 2020-04-28 03:34:51Z lloydwood $
 
 set SATS_PER_PLANE 8
 set NUM_PLANES 8
@@ -47,7 +50,8 @@ for {set j 0} {$j < $NUM_PLANES} {incr j} {
 
 	for {set i 0} {$i < $SATS_PER_PLANE} {incr i} {
 	        set T [expr $T_per * $i / $SATS_PER_PLANE - $plane_offset * $j]
-		satellites LOAD $a $e $inc $Omega $omega $T "GS-2 ($j, $i)"
+		set n [satellites LOAD $a $e $inc $Omega $omega $T "GS-2 ($j, $i)"]
+		if {$i > 0} {satellites ORBIT_SET $n 0}
 	}
 }
 
