@@ -1,4 +1,6 @@
 #
+# * 1990s VOICE SYSTEMS
+# *
 # * ICO
 # *
 # * ICO is Intermediate Circular Orbit, another term for Medium Earth
@@ -28,9 +30,8 @@
 # which is ideal for coverage.
 #
 # this script for SaVi by Lloyd Wood (lloydwood@users.sourceforge.net)
-# http://personal.ee.surrey.ac.uk/Personal/L.Wood/software/SaVi/
 #
-# $Id: ico.tcl,v 1.11 2016/01/09 23:04:34 lloydwood Exp $
+# $Id: ico.tcl 170 2020-04-28 03:34:51Z lloydwood $
 
 set SATS_PER_PLANE 5
 set NUM_PLANES 2
@@ -53,7 +54,8 @@ for {set j 0} {$j < $NUM_PLANES} {incr j} {
 	set Omega [expr $j * 360.0 / $NUM_PLANES ]
 	for {set i 0} {$i < $SATS_PER_PLANE} {incr i} {
 		set T [expr $T_per * $i / $SATS_PER_PLANE ]
-		satellites LOAD $a $e $inc $Omega $omega $T "ICO ($j, $i)"
+		set n [satellites LOAD $a $e $inc $Omega $omega $T "ICO ($j, $i)"]
+		if {$i > 0} {satellites ORBIT_SET $n 0}
 	}
 }
 satellites GV_END
