@@ -1,4 +1,6 @@
 #
+# * PROPOSAL
+# *
 # * Macrocell
 # *
 # * Macrocell was a followup proposal from Iridium, intended to provide
@@ -9,9 +11,8 @@
 # * SaVi simulation can be verified against picture on page A-8.
 #
 # this script for SaVi by Lloyd Wood (lloydwood@users.sourceforge.net)
-# http://personal.ee.surrey.ac.uk/Personal/L.Wood/software/SaVi/
 #
-# $Id: macrocell.tcl,v 1.8 2015/08/31 01:29:33 lloydwood Exp $
+# $Id: macrocell.tcl 170 2020-04-28 03:34:51Z lloydwood $
 
 set SATS_PER_PLANE 12
 set NUM_PLANES 8
@@ -39,7 +40,8 @@ for {set j 0} {$j < $NUM_PLANES} {incr j} {
 	}
 	for {set i 0} {$i < $SATS_PER_PLANE} {incr i} {
 	        set T [expr $T_per * $i / $SATS_PER_PLANE + $plane_offset]
-		satellites LOAD $a $e $inc $Omega $omega $T "Macrocell ($j, $i)"
+		set n [satellites LOAD $a $e $inc $Omega $omega $T "Macrocell ($j, $i)"]
+		if {$i > 0} {satellites ORBIT_SET $n 0}
 	}
 }
 satellites GV_END
