@@ -1,4 +1,6 @@
 #
+# * 1990s VOICE SYSTEMS - PROPOSAL
+# *
 # * Odyssey
 # *
 # * A Medium Earth Orbit (MEO) system for voice and low-rate data that was
@@ -23,9 +25,8 @@
 # basically unchanged.
 #
 # this script for SaVi by Lloyd Wood (lloydwood@users.sourceforge.net)
-# http://personal.ee.surrey.ac.uk/Personal/L.Wood/software/SaVi/
 #
-# $Id: odyssey.tcl,v 1.9 2015/08/31 01:29:33 lloydwood Exp $
+# $Id: odyssey.tcl 170 2020-04-28 03:34:51Z lloydwood $
 
 set SATS_PER_PLANE 4
 set NUM_PLANES 3
@@ -54,7 +55,8 @@ for {set j 0} {$j < $NUM_PLANES} {incr j} {
 	set T_PHASE [expr $T_per * $PHASING / 360.0 ]
 	for {set i 0} {$i < $SATS_PER_PLANE} {incr i} {
 	   set T [expr $T_per * $i / $SATS_PER_PLANE + $T_PHASE ]
-	   satellites LOAD $a $e $inc $Omega $omega $T "Odyssey ($j, $i)"
+	   set n [satellites LOAD $a $e $inc $Omega $omega $T "Odyssey ($j, $i)"]
+	   if {$i > 0} {satellites ORBIT_SET $n 0}
 	}
 }
 satellites GV_END
