@@ -1,5 +1,5 @@
 #
-# * PROPOSED LARGE BROADBAND CONSTELLATIONS - FAT PIPE DREAMS
+# * 1990s LARGE BROADBAND PROPOSALS - FAT PIPE DREAMS
 # *
 # * SkyBridge double-delta constellation
 # *
@@ -24,13 +24,11 @@
 # *
 # * Jean-Luc Palmade, Eric Frayssinhes and Erick Lansard, Constellation
 # * of non-geostationary satellites providing permanent coverage,
-# * US patent 6032902, issued 7 March 2000 to Alcatel Espace.
-# http://www.patentstorm.us/patents/6032902.html
+# * US patent 6,032,902, issued 7 March 2000 to Alcatel Espace.
 
 # this script for SaVi by Lloyd Wood (lloydwood@users.sourceforge.net)
-# http://personal.ee.surrey.ac.uk/Personal/L.Wood/software/SaVi/
 #
-# $Id: skybridge-64.tcl,v 1.14 2015/08/31 01:29:33 lloydwood Exp $
+# $Id: skybridge-64.tcl 116 2019-09-30 07:20:51Z lloydwood $
 
 
 
@@ -78,7 +76,8 @@ for {set k 0} {$k < $NUM_CONSTS} {incr k} {
         for {set i 0} {$i < $SATS_PER_PLANE} {incr i} {
 
                 set T [expr $T_per * $i / $SATS_PER_PLANE + $plane_offset]
-		satellites LOAD $a $e $inc $Omega $omega $T "SkyBridge-64 ($j, $i, $k)"
+		set n [satellites LOAD $a $e $inc $Omega $omega $T "SkyBridge-64 ($j, $i, $k)"]
+		if {$i > 0} {satellites ORBIT_SET $n 0}
 	}
     }
 }
