@@ -1,5 +1,5 @@
 #
-# * PROPOSED LARGE BROADBAND CONSTELLATIONS - FAT PIPE DREAMS
+# * 1990s LARGE BROADBAND PROPOSALS - FAT PIPE DREAMS
 # *
 # * Teledesic (288-active satellite Boeing design)
 # *
@@ -20,9 +20,8 @@
 # * the company developing the smaller MEO ICO system.
 # 
 # this script for SaVi by Lloyd Wood (lloydwood@users.sourceforge.net)
-# http://personal.ee.surrey.ac.uk/Personal/L.Wood/software/SaVi/
 #
-# $Id: teledesic-288.tcl,v 1.10 2015/08/31 01:29:33 lloydwood Exp $
+# $Id: teledesic-288.tcl 116 2019-09-30 07:20:51Z lloydwood $
 
 
 # note that planes would not be as clearly offset in reality;
@@ -62,7 +61,8 @@ for {set j 0} {$j < $NUM_PLANES} {incr j} {
                 set T [expr $T_per * ($i + $j/double($NUM_PLANES)) / \
 					$SATS_PER_PLANE + $plane_offset ]
 
-	    satellites LOAD $a $e $inc $Omega $omega $T "Teledesic-1997 ($j, $i)"
+	    set n [satellites LOAD $a $e $inc $Omega $omega $T "Teledesic-1997 ($j, $i)"]
+	    if {$i > 0} {satellites ORBIT_SET $n 0}
 	}
 }
 satellites GV_END
