@@ -1,4 +1,6 @@
 #
+# * PROPOSAL
+# *
 # * Boeing US patent 6726152
 # *
 # * See:
@@ -11,9 +13,8 @@
 # harmonic you might expect.
 #
 # this script for SaVi 1.2, by Lloyd Wood (lloydwood@users.sourceforge.net)
-# http://personal.ee.surrey.ac.uk/Personal/L.Wood/constellations/
 #
-# $Id: us-patent-6726152-boeing.tcl,v 1.5 2015/08/31 01:29:33 lloydwood Exp $
+# $Id: us-patent-6726152-boeing.tcl 170 2020-04-28 03:34:51Z lloydwood $
 
 set SATS_PER_PLANE 5
 set NUM_PLANES 4
@@ -36,7 +37,8 @@ for {set j 0} {$j < $NUM_PLANES} {incr j} {
 	set Omega [expr $j * 360.0 / $NUM_PLANES ]
 	for {set i 0} {$i < $SATS_PER_PLANE} {incr i} {
 		set T [expr $T_per * $i / $SATS_PER_PLANE + $T_per * $j * $offset/360]
-		satellites LOAD $a $e $inc $Omega $omega $T "Boeing-Higgins ($j, $i)"
+		set n [satellites LOAD $a $e $inc $Omega $omega $T "Boeing-Higgins ($j, $i)"]
+		if {$i > 0} {satellites ORBIT_SET $n 0}
 	}
 }
 satellites GV_END
