@@ -1,15 +1,23 @@
 #
+# * MEDIUM EARTH ORBIT (MEO) SYSTEMS - PROPOSAL
+# *
 # * ViaSat NGSO
 # *
-# * A Medium Earth Orbit (MEO) system. 
+# * Originally described in ViaSat's filing to the US FCC: Petition
+# * for Declaratory Ruling, SAT-LOI-20161115-00120, 15 November 2016.
+# * Later reduced from 24 to 20 satellites (four planes of five
+# * satellites) at the same altitude, in a November 2018 modification.
 # *
-# * Described in ViaSat's filing to the US FCC: Petition for
-# * Declatory Ruling, SAT-LOI-20161115-00120, 15 November 2016.
+# * The application was again later modified in May 2020 to be a LEO
+# * system, modelled in a separate script.
 #
 # this script for SaVi by Lloyd Wood (lloydwood@users.sourceforge.net)
 # http://savi.sourceforge.net/
 #
-# $Id: viasat-ngso.tcl,v 1.1 2016/11/19 07:15:52 lloydwood Exp $
+# https://spacenews.com/viasat-shrinks-meo-constellation-plans/
+# Viasat shrinks MEO constellation plans, Caleb Henry, 5 November 2018.
+#
+# $Id: viasat-ngso.tcl 177 2020-05-27 04:40:43Z lloydwood $
 
 set SATS_PER_PLANE 8
 set NUM_PLANES 3
@@ -39,7 +47,8 @@ for {set j 0} {$j < $NUM_PLANES} {incr j} {
 	set T_PHASE [expr $T_per * $PHASING / 360.0 ]
 	for {set i 0} {$i < $SATS_PER_PLANE} {incr i} {
 	   set T [expr $T_per * $i / $SATS_PER_PLANE + $T_PHASE ]
-	   satellites LOAD $a $e $inc $Omega $omega $T "ViaSat NGSO ($j, $i)"
+	   set n [satellites LOAD $a $e $inc $Omega $omega $T "ViaSat NGSO ($j, $i)"]
+	   if {$i > 0} {satellites ORBIT_SET $n 0}
 	}
 }
 satellites GV_END
