@@ -21,7 +21,7 @@
  *
  * coverage.c
  *
- * $Id: coverage.c,v 1.47 2017/01/02 06:11:32 lloydwood Exp $
+ * $Id: coverage.c 135 2020-01-04 10:04:48Z lloydwood $
  */
 #include <math.h>
 #include <stdlib.h>
@@ -78,6 +78,36 @@ update_coverage_display(void)
 		 tracks_flag, project_tracks_flag);
 }
 
+/*
+ * coverage_map_on_cmd
+ */
+char *
+coverage_map_on_cmd(int argc, char *argv[])
+{
+  if (c_grid) {
+    destroy_grid(c_grid);
+    c_grid = create_grid(Image_Height, Image_Width);
+  }
+  
+  image_init(c_grid);
+  
+  return EMPTY_str;
+}
+
+/*
+ * coverage_map_off_cmd
+ */
+char *
+coverage_map_off_cmd(int argc, char *argv[])
+{
+  if (c_grid) {
+    /* could do destroy_grid(c_grid); */
+  }
+
+  return EMPTY_str;
+}
+
+
 /*
  * coverage_on_cmd -
  * Set flags to indicate that coverage should be actually computed and
@@ -503,6 +533,47 @@ coverage_save_map_cmd(int argc, char *argv[])
     return EMPTY_str;
 }
 
+char *
+coverage_save_plot_cmd(int argc, char *argv[])
+{
+  Constellation *pconstellation;
+  CentralBody *pcb;
+  Satellite_list sl;
+  LatLon pl;
+  double time;
+
+  FILE *f;
+
+  pconstellation = get_constellation();
+  pcb = pconstellation->pcb;
+  sl = pconstellation->satellites;
+
+  if (NULL == (f = fopen(argv[2], "w"))) {
+    fprintf(stderr,"\nSaVi: unable to save dump file to %s", argv[2]);
+    return EMPTY_str;
+  }
+
+  time = current_time();
+
+  fprintf(f, "Dumping satellites at time %f\n", time);
+
+  /* first in list in sunlight - skip it. */
+  if (sl) sl = sl->next;
+
+  while (sl) {
+    spherical_to_lat_lon(&pl, &(sl->s->x_S), sl->s->t, pcb);
+    /* meed to modify sat plot scripts to support name, not just number */
+    fprintf(f, "%s\t%f\t%f\n",sl->s->name, pl.lat, pl.lon);
+    sl = sl->next;
+  }
+
+  fclose(f);
+
+  fprintf(stderr, "\nSaVi: satellite plot script input written to %s", argv[2]);
+
+  return EMPTY_str;
+}
+
 char *
 coverage_color_update_cmd(int argc, char *argv[])
 {
