@@ -22,7 +22,7 @@
  *
  * Coverage visualization routines.
  *
- * $Id: coverage_vis.c,v 1.138 2017/06/28 11:09:50 lloydwood Exp $
+ * $Id: coverage_vis.c 191 2023-04-02 04:27:41Z lloydwood $
  */
 
 #include <math.h>
@@ -107,9 +107,9 @@ typedef struct RGB {
 } RGB;
 
 /* Colors for coverage intensity (in RGB values)  */
-/* We allow up to twenty values, for 0 to 19. *3, gives us 60. */
-static unsigned char colors[60];
-static unsigned char noaccess_colors[60];
+/* We allow up to thirty values, for 0 to 29. *3, gives us 90. */
+static unsigned char colors[90];
+static unsigned char noaccess_colors[90];
 
 /* Color for earth outline and ground track - see enum in coverage_vis.h */
 static unsigned char outline_colors[] = { 255, 255, 255,  /* background */
@@ -189,6 +189,16 @@ coverage_color_copy(void)
   color_hex(DIV17, (RGB *) &COLDIV[51]);
   color_hex(DIV18, (RGB *) &COLDIV[54]);
   color_hex(DIV19, (RGB *) &COLDIV[57]);
+  color_hex(DIV20, (RGB *) &COLDIV[60]);
+  color_hex(DIV21, (RGB *) &COLDIV[63]);
+  color_hex(DIV22, (RGB *) &COLDIV[66]);
+  color_hex(DIV23, (RGB *) &COLDIV[69]);
+  color_hex(DIV24, (RGB *) &COLDIV[72]);
+  color_hex(DIV25, (RGB *) &COLDIV[75]);
+  color_hex(DIV26, (RGB *) &COLDIV[78]);
+  color_hex(DIV27, (RGB *) &COLDIV[81]);
+  color_hex(DIV28, (RGB *) &COLDIV[84]);
+  color_hex(DIV29, (RGB *) &COLDIV[87]);
 
   color_hex(DEC0, (RGB *) &COLDEC[0]);
   color_hex(DEC1, (RGB *) &COLDEC[3]);
@@ -210,7 +220,16 @@ coverage_color_copy(void)
   color_hex(DEC17, (RGB *) &COLDEC[51]);
   color_hex(DEC18, (RGB *) &COLDEC[54]);
   color_hex(DEC19, (RGB *) &COLDEC[57]);
-
+  color_hex(DEC20, (RGB *) &COLDEC[60]);
+  color_hex(DEC21, (RGB *) &COLDEC[63]);
+  color_hex(DEC22, (RGB *) &COLDEC[66]);
+  color_hex(DEC23, (RGB *) &COLDEC[69]);
+  color_hex(DEC24, (RGB *) &COLDEC[72]);
+  color_hex(DEC25, (RGB *) &COLDEC[75]);
+  color_hex(DEC26, (RGB *) &COLDEC[78]);
+  color_hex(DEC27, (RGB *) &COLDEC[81]);
+  color_hex(DEC28, (RGB *) &COLDEC[84]);
+  color_hex(DEC29, (RGB *) &COLDEC[87]);
 
 }
 
@@ -261,7 +280,10 @@ image_init(grid * g)
      return;
   }
 
-  image = (Tk_PhotoImageBlock *) malloc(sizeof(Tk_PhotoImageBlock));
+  if (!image) {
+    image = (Tk_PhotoImageBlock *) malloc(sizeof(Tk_PhotoImageBlock));
+  }
+  /* this will leak memory until fixed */
   image->pixelPtr = (unsigned char *) malloc(image_size * PIXELSIZE *
 					     sizeof(unsigned char *));
   image->width = width;
@@ -272,93 +294,58 @@ image_init(grid * g)
   image->offset[1] = 1;
   image->offset[2] = 2;
 
-  if (!foreground) {
-    foreground = (unsigned char *) malloc(sizeof(char) * image_size);
+  {
+    if (foreground) free (foreground);
+    foreground = (unsigned char *) calloc(sizeof(char) * image_size, 1);
 
-    cyl_foreground = (unsigned char *) malloc(sizeof(char) * image_size);
-    sin_foreground = (unsigned char *) malloc(sizeof(char) * image_size);
-    sin_90_foreground = (unsigned char *) malloc(sizeof(char) * image_size);
-    unp_foreground = (unsigned char *) malloc(sizeof(char) * image_size);
-    unp_mask_foreground = (unsigned char *) malloc(sizeof(char) * image_size);
-    sph_foreground = (unsigned char *) malloc(sizeof(char) * image_size);
-    sph_90_foreground = (unsigned char *) malloc(sizeof(char) * image_size);
+    if (coverage_all_projections) {
+      if (cyl_foreground) free (cyl_foreground);
+      cyl_foreground = (unsigned char *) calloc(sizeof(char) * image_size, 1);
+
+      if (sin_foreground) free (sin_foreground);
+      sin_foreground = (unsigned char *) calloc(sizeof(char) * image_size, 1);
+
+      if (sin_90_foreground) free (sin_90_foreground);
+      sin_90_foreground = (unsigned char *) calloc(sizeof(char) * image_size, 1);
+    }
+    
+    if (unp_foreground) free (unp_foreground);
+    unp_foreground = (unsigned char *) calloc(sizeof(char) * image_size, 1);
+
+    if (unp_mask_foreground) free (unp_mask_foreground);
+    unp_mask_foreground = (unsigned char *) calloc(sizeof(char) * image_size, 1);
+
+    if (sph_foreground) free (sph_foreground);
+    sph_foreground = (unsigned char *) calloc(sizeof(char) * image_size, 1);
+    
+    if (sph_90_foreground) free (sph_90_foreground);
+    sph_90_foreground = (unsigned char *) calloc(sizeof(char) * image_size, 1);
 
     if (width == IMAGE_LARGE_WIDTH) {
-      made = overlay_bitmap(height, width, cyl_foreground, CYLINDRICAL_LARGE_BITMAP_NAME);
-      if (!made) {
-	free(cyl_foreground);
-	cyl_foreground = NULL;
-      }
-      made = overlay_bitmap(height, width, sin_foreground, SINUSOIDAL_LARGE_BITMAP_NAME);
-      if (!made) {
-	free(sin_foreground);
-	sin_foreground = NULL;
-      }
-      made = overlay_bitmap(height, width, sin_90_foreground, SINUSOIDAL_90_LARGE_BITMAP_NAME);
-      if (!made) {
-	free(sin_90_foreground);
-	sin_90_foreground = NULL;
-      }
       made = overlay_bitmap(height, width, unp_foreground, UNPROJECTED_LARGE_BITMAP_NAME);
-      if (!made) {
-	free(unp_foreground);
-	unp_foreground = NULL;
-      }
       made = overlay_bitmap(height, width, unp_mask_foreground, UNPROJECTED_MASK_LARGE_BITMAP_NAME);
-      if (!made) {
-	free(unp_mask_foreground);
-	unp_mask_foreground = NULL;
-      }
       made = overlay_bitmap(height, width, sph_foreground, SPHERICAL_LARGE_BITMAP_NAME);
-      if (!made) {
-	free(sph_foreground);
-	sph_foreground = NULL;
-      }
       made = overlay_bitmap(height, width, sph_90_foreground, SPHERICAL_90_LARGE_BITMAP_NAME);
-      if (!made) {
-        free(sph_90_foreground);
-        sph_90_foreground = NULL;
-      }
-
-    } else {
-      made = overlay_bitmap(height, width, cyl_foreground, CYLINDRICAL_BITMAP_NAME);
-      if (!made) {
-	free(cyl_foreground);
-	cyl_foreground = NULL;
-      }
-      made = overlay_bitmap(height, width, sin_foreground, SINUSOIDAL_BITMAP_NAME);
-      if (!made) {
-	free(sin_foreground);
-	sin_foreground = NULL;
-      }
-      made = overlay_bitmap(height, width, sin_90_foreground, SINUSOIDAL_90_BITMAP_NAME);
-      if (!made) {
-	free(sin_90_foreground);
-	sin_90_foreground = NULL;
+      if (coverage_all_projections) {
+        made = overlay_bitmap(height, width, cyl_foreground, CYLINDRICAL_LARGE_BITMAP_NAME);
+        made = overlay_bitmap(height, width, sin_foreground, SINUSOIDAL_LARGE_BITMAP_NAME);
+        made = overlay_bitmap(height, width, sin_90_foreground, SINUSOIDAL_90_LARGE_BITMAP_NAME);
       }
+    } else if (width == IMAGE_WIDTH) {
       made = overlay_bitmap(height, width, unp_foreground, UNPROJECTED_BITMAP_NAME);
-      if (!made) {
-	free(unp_foreground);
-	unp_foreground = NULL;
-      }
       made = overlay_bitmap(height, width, unp_mask_foreground, UNPROJECTED_MASK_BITMAP_NAME);
-      if (!made) {
-	free(unp_mask_foreground);
-	unp_mask_foreground = NULL;
-      }
       made = overlay_bitmap(height, width, sph_foreground, SPHERICAL_BITMAP_NAME);
-      if (!made) {
-	free(sph_foreground);
-	sph_foreground = NULL;
-      }
       made = overlay_bitmap(height, width, sph_90_foreground, SPHERICAL_90_BITMAP_NAME);
-      if (!made) {
-	free(sph_90_foreground);
-	sph_90_foreground = NULL;
+      if (coverage_all_projections) {
+        made = overlay_bitmap(height, width, cyl_foreground, CYLINDRICAL_BITMAP_NAME);
+        made = overlay_bitmap(height, width, sin_foreground, SINUSOIDAL_BITMAP_NAME);
+        made = overlay_bitmap(height, width, sin_90_foreground, SINUSOIDAL_90_BITMAP_NAME);
       }
     }
 
-    draw_sin_map_edges(g);
+    if (coverage_all_projections) {
+      draw_sin_map_edges(g);
+    }
   }
 }
 
@@ -737,10 +724,12 @@ overlay_bitmap(unsigned int h, unsigned int w, unsigned char *b,
       }
     }
   } else {
-    fprintf(stderr, "\nSaVi: %s has unexpected pbm header format: P%d %d %d",
-	    filename, pbmtype, width, height);
-    fprintf(stderr, "\n      was expecting the pbm header format: P4 %d %d\n",
-	    w, h);
+    if (debug) {
+      fprintf(stderr, "\nSaVi: %s has unexpected pbm header format: P%d %d %d",
+	      filename, pbmtype, width, height);
+      fprintf(stderr, "\n      was expecting the pbm header format: P4 %d %d\n",
+	      w, h);
+    }
     fclose(f);
     return FALSE;
   }
