@@ -22,7 +22,7 @@
  *
  * declaration and initialization of global variables.
  *
- * $Id: globals.c,v 1.51 2017/06/07 21:34:22 lloydwood Exp $
+ * $Id: globals.c 190 2023-04-02 03:52:19Z lloydwood $
  */
 
 #include <limits.h>
@@ -33,6 +33,7 @@
 /* Is program running as a Geomview module? */
 int geomview_module = FALSE;
 int fake_geomview_module = FALSE;
+int geomview_oogl_verbose = FALSE;
 int geomview_logo = TRUE;
 
 /* has texturemapping been turned on? */
@@ -74,6 +75,8 @@ int splash_about = FALSE;
 /* Known to fail on Mac OS X 10.5 Leopard, hence this fallback method */
 int buttons_menu = FALSE;
 
+int coverage_all_projections = FALSE;
+
 unsigned char * cyl_foreground = NULL;
 unsigned char * sin_foreground = NULL;
 unsigned char * unp_foreground = NULL;
