@@ -22,13 +22,13 @@
  *
  * Global variable declarations
  *
- * $Id: globals.h,v 1.58 2017/06/07 21:34:22 lloydwood Exp $
+ * $Id: globals.h 190 2023-04-02 03:52:19Z lloydwood $
  */
 
 #ifndef _GLOBALS_H_
 #define _GLOBALS_H_
 
-#define LENGTH_STRING_BUFFER 256
+#define LENGTH_STRING_BUFFER 2048
 
 char cmd[LENGTH_STRING_BUFFER];
 
@@ -36,6 +36,7 @@ char command_switches[LENGTH_STRING_BUFFER];
 
 int geomview_module; /* TRUE if program is a geomview module */
 int fake_geomview_module; /* TRUE if pretending to run under geomview */
+int geomview_oogl_verbose; /* TRUE if sending comments to geomview or log */
 int geomview_logo; /* TRUE if SaVi logo is shown on camera */
 
 int texture_flag; /* TRUE if we're texturemapping */
@@ -54,6 +55,8 @@ int plane_flag; /* TRUE if we want to see equatorial plane */
 int sun_flag; /* TRUE if we want to see sun lighting */
 int fisheye_viewpoint_flag; /* TRUE if we want to plot location on coverage */
 
+int coverage_all_projections; /* TRUE if we want to see not-very-useful projections */
+
 int debug;
 int splash_about;
 int buttons_menu;
@@ -72,11 +75,11 @@ int orbit_model;
 typedef enum {
   UNPROJECTED_MASK=0,
   UNPROJECTED,
-  CYLINDRICAL,
-  SINUSOIDAL,
-  SINUSOIDAL_90,
   SPHERICAL,
   SPHERICAL_90,
+  SINUSOIDAL,
+  SINUSOIDAL_90,
+  CYLINDRICAL,
   NUM_PROJECTIONS
 } coverage_projections;
 
@@ -125,9 +128,11 @@ int Fisheye_Diameter;
 /* coverage colors */
 int DIV0, DIV1, DIV2, DIV3, DIV4, DIV5, DIV6, DIV7, DIV8, DIV9;
 int DIV10, DIV11, DIV12, DIV13, DIV14, DIV15, DIV16, DIV17, DIV18, DIV19;
+int DIV20, DIV21, DIV22, DIV23, DIV24, DIV25, DIV26, DIV27, DIV28, DIV29;
 
 int DEC0, DEC1, DEC2, DEC3, DEC4, DEC5, DEC6, DEC7, DEC8, DEC9;
 int DEC10, DEC11, DEC12, DEC13, DEC14, DEC15, DEC16, DEC17, DEC18, DEC19;
+int DEC20, DEC21, DEC22, DEC23, DEC24, DEC25, DEC26, DEC27, DEC28, DEC29;
 
 #endif
 /* !_GLOBALS_H_ */
