@@ -22,7 +22,7 @@
  *
  * headers for the different functions
  *
- * $Id: savi.h,v 1.33 2017/01/02 06:11:32 lloydwood Exp $
+ * $Id: savi.h 133 2020-01-04 09:17:43Z lloydwood $
  */
 
 #ifndef _SAVI_H_
@@ -123,6 +123,8 @@ void coverage_compute(const Satellite_list sl, unsigned int,
 		      const CentralBody *pcb);
 void coverage_display(const Satellite_list sl, unsigned int,
 		      const CentralBody *pcb);
+char *coverage_map_on_cmd(int argc, char *argv[]);
+char *coverage_map_off_cmd(int argc, char *argv[]);
 char *coverage_on_cmd(int argc, char *argv[]);
 char *coverage_off_cmd(int argc, char *argv[]);
 char *coverage_set_cmd(int argc, char *argv[]);
@@ -142,6 +144,7 @@ char *project_tracks_off_cmd(int argc, char *argv[]);
 void project_tracks_reset(void);
 char *coverage_proj_cmd(int argc, char *argv[]);
 char *coverage_save_map_cmd(int argc, char *argv[]);
+char *coverage_save_plot_cmd(int argc, char *argv[]);
 char *coverage_angle_type_cmd(int argc, char *argv[]);
 char *coverage_color_update_cmd(int argc, char *argv[]);
 double mean_coverage(int projection_type, grid *g);
