@@ -6,7 +6,7 @@
  *          Robert Thurman.
  *
  *  Copyright (c) 1997 by The Geometry Center.
- *  Also Copyright (c) 2016 by Lloyd Wood.
+ *  Also Copyright (c) 2017 by Lloyd Wood.
  *
  *  This file is part of SaVi.  SaVi is free software;
  *  you can redistribute it and/or modify it only under
@@ -20,7 +20,7 @@
  *
  * main.c
  *
- * $Id: main.c,v 1.90 2016/09/01 05:46:59 lloydwood Exp $
+ * $Id: main.c 190 2023-04-02 03:52:19Z lloydwood $
  */
 
 #include <stdio.h>
@@ -142,7 +142,8 @@ decode_cmd_line(int argc, char *argv[])
 
   int give_version = FALSE;
   int give_help = FALSE;
-  int coverage_large_map = FALSE;
+  int coverage_large_map = TRUE;
+  int coverage_map_type_set = FALSE;
   int not_fake_geomview = FALSE;
   int levels_error = FALSE;
   int levels_format_error = FALSE;
@@ -152,6 +153,7 @@ decode_cmd_line(int argc, char *argv[])
   int map_view_error = FALSE;
   int map_view_height = 0;
   int min_transmit_altitude_error = FALSE;
+  int max_transmit_altitude_error = FALSE;
   int length_savi_name, length_switches;
   unsigned int i;
 
@@ -171,7 +173,19 @@ decode_cmd_line(int argc, char *argv[])
       special_flags_done++;
       give_help = TRUE;
     } else if (strcmp(argv[i], "-large-map") == 0) {
+      if (coverage_map_type_set) {
+	error("Large map now? Another map size was already chosen.");
+      }
       coverage_large_map = TRUE;
+      coverage_map_type_set = TRUE;
+    } else if (strcmp(argv[i], "-small-map") == 0) {
+      if (coverage_map_type_set) {
+	error("Small map now? Another map size was already chosen.");
+      }	
+      coverage_large_map = FALSE;
+      coverage_map_type_set = TRUE;
+    } else if (strcmp(argv[i], "-all-maps") == 0) {
+      coverage_all_projections = TRUE;
     } else if (strcmp(argv[i], "-dynamic-texture-with-map") == 0) {
       geomview_texture_with_map = TRUE;
     } else if (strcmp(argv[i], "-gzip-compressed-textures") == 0) {
@@ -189,11 +203,13 @@ decode_cmd_line(int argc, char *argv[])
       splash_about = TRUE;
     } else if (strcmp(argv[i], "-sun-lighting") == 0) {
       geomview_sun_lighting = TRUE;
+    } else if (strcmp(argv[i], "-verbose") == 0) {
+      geomview_oogl_verbose = TRUE;
     } else if (strcmp(argv[i],"-levels") == 0) {
       if (++i < argc) {
 	if (sscanf((char *) argv[i], "%i", &NUM_COLORS) == 1) {
 	  if ((NUM_COLORS < 1) ||
-	      (NUM_COLORS > 19)) {
+	      (NUM_COLORS > 29)) {
 	    NUM_COLORS = 0;
 	    levels_error = TRUE;
           }
@@ -242,6 +258,13 @@ decode_cmd_line(int argc, char *argv[])
           i--;
         }
       }
+    } else if (strcmp(argv[i],"-max-transmit-altitude") == 0) {
+      if (++i < argc) {
+        if (sscanf((char *) argv[i], "%i", &max_transmit_altitude) != 1) {
+          max_transmit_altitude_error = TRUE;
+          i--;
+        }
+      }
     } else if (strncmp(argv[i],"-",1) == 0) {
       unknown_parameters++;
     } else if (!script_filename) {
@@ -281,15 +304,16 @@ decode_cmd_line(int argc, char *argv[])
   }
 
   if (give_help) {
-    error("supported command-line options include:\n"
-	  "savi [-large-map] [-levels <n>] [-debug] [-fake-geomview] [-redrawn-menus]\n"
+    error("supported command-line options when SaVi is run standalone include:\n"
+	  "savi [-large-map] [-small-map] [-levels <n>] [-all-maps] [-fake-geomview]\n"
 	  "     [-map-view-height <no. of pixels>] [-map-view-middle <longitude>] \n"
-          "     [-min-transmit-altitude <kilometers> ] [-orbit-model <J0|J2>]  [filename]\n"
-	  "  when SaVi is run standalone. Further flags:\n"
+          "     [-max-transmit-altitude <kilometers>] [-min-transmit-altitude <kilometers>]\n"
+	  "     [-orbit-model <J0|J2>] [-redrawn-menus] [-debug] [filename]");
+    error("further flags become available when SaVi is run from Geomview:\n"
 	  "savi [-geomview] [-dynamic-texture-with-map] [-gzip-compressed-textures]\n"
-	  "     [-uncompressed] [-no-logo] [-sun-lighting]\n"
-	  "  are available when SaVi is run from Geomview.\n");
-    error("\nsavi -help shows this help information at the command line.\n"
+	  "     [-uncompressed] [-verbose] [-no-logo] [-sun-lighting]");
+    error("other useful flags:\n"
+	  "savi -help repeats this help information at the command line.\n"
           "savi -version provides version information at the command line.\n"
 	  "savi -splash shows copyright and version information in a window.\n");
     sprintf(temp_buffer," -help");
@@ -354,6 +378,12 @@ decode_cmd_line(int argc, char *argv[])
     }
   }
 
+  if (geomview_oogl_verbose) {
+    sprintf(temp_buffer," -verbose");
+    sprintf(switches, temp_buffer);
+    switches += strlen(temp_buffer);
+  }
+
   if (!can_use_zlib) {
     error("compiled without zlib compression.");
   }
@@ -406,11 +436,24 @@ decode_cmd_line(int argc, char *argv[])
   if (min_transmit_altitude_error) {
     error("format is -min-transmit-altitude <kilometers>");
   }
+  if (max_transmit_altitude_error) {
+    error("format is -max-transmit-altitude <kilometers>");
+  }
 
-  if (min_transmit_altitude) {
+  if (min_transmit_altitude > 0) {
     sprintf(temp_buffer, " -min-transmit-altitude %i", min_transmit_altitude);
     sprintf(switches, temp_buffer);
     switches += strlen(temp_buffer);
+  } else {
+    min_transmit_altitude = -1;
+  }
+
+  if (max_transmit_altitude > 0) {
+    sprintf(temp_buffer, " -max-transmit-altitude %i", max_transmit_altitude);
+    sprintf(switches, temp_buffer);
+    switches += strlen(temp_buffer);
+  } else {
+    max_transmit_altitude = -1;
   }
 
   if (buttons_menu) {
@@ -418,6 +461,12 @@ decode_cmd_line(int argc, char *argv[])
     sprintf(switches, temp_buffer);
     switches += strlen(temp_buffer);
   }
+  
+  if (coverage_all_projections) {
+    sprintf(temp_buffer, "-all-maps");
+    sprintf(switches, temp_buffer);
+    switches += strlen(temp_buffer);
+  }
 
   if (debug) {
     sprintf(temp_buffer, " -debug");
@@ -433,13 +482,22 @@ decode_cmd_line(int argc, char *argv[])
     sprintf(temp_buffer," -map-view-height %i", map_view_height);
     sprintf(switches, temp_buffer);
     switches += strlen(temp_buffer);
-  } else if (coverage_large_map) {
+  } else if (coverage_map_type_set) {
+    if (coverage_large_map) {
       Image_Width = IMAGE_LARGE_WIDTH;
       Image_Height = IMAGE_LARGE_HEIGHT;
       error("large default map size selected.");
       sprintf(temp_buffer," -large-map");
       sprintf(switches, temp_buffer);
       switches += strlen(temp_buffer);
+    } else {
+      Image_Width = IMAGE_WIDTH;
+      Image_Height = IMAGE_HEIGHT;
+      error("small default map size selected.");
+      sprintf(temp_buffer," -small-map");
+      sprintf(switches, temp_buffer);
+      switches += strlen(temp_buffer);
+    }
   }
 
   if (coverage_display_center_longitude) {
