@@ -20,7 +20,7 @@
  *
  * tcl_utils.c
  *
- * $Id: tcl_utils.c,v 1.45 2017/06/26 04:33:07 lloydwood Exp $
+ * $Id: tcl_utils.c 190 2023-04-02 03:52:19Z lloydwood $
  */
 
 #include "constants.h"
@@ -180,11 +180,32 @@ tcl_app_init()
   static char var56[] = "DEC(18)";
   static char var57[] = "DIV(19)";
   static char var58[] = "DEC(19)";
-  static char var59[] = "buttons_menu";
-  static char var60[] = "min_transmit_altitude";
-  static char var61[] = "parallels_angle";
-  static char var62[] = "equatorial_exclusion_angle";
-
+  static char var59[] = "DIV(20)";
+  static char var60[] = "DEC(20)";
+  static char var61[] = "DIV(21)";
+  static char var62[] = "DEC(21)";
+  static char var63[] = "DIV(22)";
+  static char var64[] = "DEC(22)";
+  static char var65[] = "DIV(23)";
+  static char var66[] = "DEC(23)";
+  static char var67[] = "DIV(24)";
+  static char var68[] = "DEC(24)";
+  static char var69[] = "DIV(25)";
+  static char var70[] = "DEC(25)";
+  static char var71[] = "DIV(26)";
+  static char var72[] = "DEC(26)";
+  static char var73[] = "DIV(27)";
+  static char var74[] = "DEC(27)";
+  static char var75[] = "DIV(28)";
+  static char var76[] = "DEC(28)";
+  static char var77[] = "DIV(29)";
+  static char var78[] = "DEC(29)";
+  static char var79[] = "buttons_menu";
+  static char var80[] = "min_transmit_altitude";
+  static char var81[] = "parallels_angle";
+  static char var82[] = "equatorial_exclusion_angle";
+  static char var83[] = "coverage_all_projections";
+  
   unsigned int test;
 
   /* add directory of tcl code */
@@ -259,10 +280,31 @@ tcl_app_init()
   Tcl_LinkVar(interp, var56, (char *) &DEC18, TCL_LINK_INT);
   Tcl_LinkVar(interp, var57, (char *) &DIV19, TCL_LINK_INT);
   Tcl_LinkVar(interp, var58, (char *) &DEC19, TCL_LINK_INT);
-  Tcl_LinkVar(interp, var59, (char *) &buttons_menu, TCL_LINK_INT);
-  Tcl_LinkVar(interp, var60, (char *) &min_transmit_altitude, TCL_LINK_INT);
-  Tcl_LinkVar(interp, var61, (char *) &parallels_angle, TCL_LINK_DOUBLE);
-  Tcl_LinkVar(interp, var62, (char *) &equatorial_exclusion_angle, TCL_LINK_DOUBLE);
+  Tcl_LinkVar(interp, var59, (char *) &DIV20, TCL_LINK_INT);
+  Tcl_LinkVar(interp, var60, (char *) &DEC20, TCL_LINK_INT);
+  Tcl_LinkVar(interp, var61, (char *) &DIV21, TCL_LINK_INT);
+  Tcl_LinkVar(interp, var62, (char *) &DEC21, TCL_LINK_INT);
+  Tcl_LinkVar(interp, var63, (char *) &DIV22, TCL_LINK_INT);
+  Tcl_LinkVar(interp, var64, (char *) &DEC22, TCL_LINK_INT);
+  Tcl_LinkVar(interp, var65, (char *) &DIV23, TCL_LINK_INT);
+  Tcl_LinkVar(interp, var66, (char *) &DEC23, TCL_LINK_INT);
+  Tcl_LinkVar(interp, var67, (char *) &DIV24, TCL_LINK_INT);
+  Tcl_LinkVar(interp, var68, (char *) &DEC24, TCL_LINK_INT);
+  Tcl_LinkVar(interp, var69, (char *) &DIV25, TCL_LINK_INT);
+  Tcl_LinkVar(interp, var70, (char *) &DEC25, TCL_LINK_INT);
+  Tcl_LinkVar(interp, var71, (char *) &DIV26, TCL_LINK_INT);
+  Tcl_LinkVar(interp, var72, (char *) &DEC26, TCL_LINK_INT);
+  Tcl_LinkVar(interp, var73, (char *) &DIV27, TCL_LINK_INT);
+  Tcl_LinkVar(interp, var74, (char *) &DEC27, TCL_LINK_INT);
+  Tcl_LinkVar(interp, var75, (char *) &DIV28, TCL_LINK_INT);
+  Tcl_LinkVar(interp, var76, (char *) &DEC28, TCL_LINK_INT);
+  Tcl_LinkVar(interp, var77, (char *) &DIV29, TCL_LINK_INT);
+  Tcl_LinkVar(interp, var78, (char *) &DEC29, TCL_LINK_INT);
+  Tcl_LinkVar(interp, var79, (char *) &buttons_menu, TCL_LINK_INT);
+  Tcl_LinkVar(interp, var80, (char *) &min_transmit_altitude, TCL_LINK_INT);
+  Tcl_LinkVar(interp, var81, (char *) &parallels_angle, TCL_LINK_DOUBLE);
+  Tcl_LinkVar(interp, var82, (char *) &equatorial_exclusion_angle, TCL_LINK_DOUBLE);
+  Tcl_LinkVar(interp, var83, (char *) &coverage_all_projections, TCL_LINK_INT);
 
   /* execute initialization */
   {
