@@ -20,7 +20,7 @@
  *
  * utils.c
  *
- * $Id: utils.c,v 1.21 2017/01/02 06:11:32 lloydwood Exp $
+ * $Id: utils.c 146 2020-01-16 02:14:25Z lloydwood $
  */
 #include <stdlib.h>
 #include <stdio.h>
@@ -51,7 +51,15 @@ copyfile(FILE * out_fp, const char filename[])
   if (NULL == (in_fp = fopen(filename, "r")))
     return FALSE;
   while (fgets(buf, LENGTH_STRING_BUFFER, in_fp)) {
-    fprintf(out_fp, "%s", buf);
+    /* skip comments - 35 is ASCII for hash, followed by space or return. */
+    /* but doesn't handle multiline coomments indicated by backslash! */
+    if ((35 == buf[0]) && \
+	((32 == buf[1]) || (13 == buf[1])) && \
+	!geomview_oogl_verbose) {
+      /* skip line and do nothing */
+    } else {
+      fprintf(out_fp, "%s", buf);
+    }
   }
   fflush(out_fp);
   fclose(in_fp);
