@@ -20,15 +20,15 @@
 #
 # coverage.tcl
 #
-# $Id: coverage.tcl,v 1.176 2017/07/02 11:07:11 lloydwood Exp $
+# $Id: coverage.tcl 190 2023-04-02 03:52:19Z lloydwood $
 
 # Note: IM_W and IM_H are linked to C variables for the image size
 
 proc coverage(init) {} {
     global coverage_flag no_access_flag print_access_flag tracks_flag map_flag \
 	project_tracks_flag coverage_proj_flag coverage_angle_flag \
-	coverage_flag_dismissed tracks_flag_dismissed no_access_flag_dismissed \
-	Projection coverage_projection last_coverage_projection NUM_COLORS_PREV
+	coverage_flag_dismissed tracks_flag_dismissed \
+	Projection coverage_projection last_coverage_projection NUM_COLORS_PREV NUM_COLORS
 
     trace variable coverage_flag w flag_change
     trace variable no_access_flag w flag_change
@@ -53,14 +53,16 @@ proc coverage(init) {} {
     set coverage_flag_dismissed 1
     set tracks_flag_dismissed 1
 
-    # this and popup menu match master list in globals.h
+    
+    # this and popup menu must match master list in globals.h
+    # reordered to place less useful projections at end.
     set Projection(unprojected_mask) 0
     set Projection(unprojected) 1
-    set Projection(cylindrical) 2
-    set Projection(sinusoidal) 3
-    set Projection(sinusoidal_90) 4
-    set Projection(spherical) 5
-    set Projection(spherical_90) 6
+    set Projection(spherical) 2
+    set Projection(spherical_90) 3
+    set Projection(sinusoidal) 4
+    set Projection(sinusoidal_90) 5
+    set Projection(cylindrical) 6
 
     set coverage_projection $Projection(unprojected)
     set last_coverage_projection $coverage_projection
@@ -69,17 +71,21 @@ proc coverage(init) {} {
 }
 
 proc coverage(build) {} {
-    global FONT COLOR COLDIV COLDEC coverage_flag no_access_flag tracks_flag \
-	coverage_proj_flag coverage_angle_flag project_tracks_flag map_flag \
-	coverage_projection coverage_angle im IM_W IM_H im_x_offset im_y_offset \
-	coverage_flag_dismissed tracks_flag_dismissed no_access_flag_dismissed \
-	coverage_display_center_longitude coverage_name \
+    global FONT COLOR coverage_flag no_access_flag tracks_flag \
+	coverage_angle_flag project_tracks_flag map_flag \
+	coverage_projection coverage_angle IM_H IM_W \
+	coverage_flag_dismissed tracks_flag_dismissed \
+	coverage_name coverage_all_projections \
 	sun_flag Fisheye NUM_COLORS NUM_COLORS_PREV
 
-
-    if {($IM_H == 0) || ($NUM_COLORS == 0)} {
-	coverage_size(build)
-	return
+    if {$IM_H == 0} {
+        # default to large map
+	set IM_H 512
+	set IM_W 1024
+    }
+    if {$NUM_COLORS == 0} {
+	# for large map
+	set NUM_COLORS 14
     }
     
     if {[eval window(raise) coverage]} return
@@ -107,6 +113,7 @@ proc coverage(build) {} {
 	     {} \
 	     {"Save map..." "coverage(save_map)" "M"} \
              {"Save animation..." "coverage_frames(build)"} \
+	     {"Save satellites map for plot script..." main(save_plot)} \
 	     {} \
 	     {"Load color shades..." "coverage(load_colors)"} \
 	     {"Save color shades..." "coverage(save_colors)"} \
@@ -132,20 +139,29 @@ proc coverage(build) {} {
 	{"Rendering"} \
 	{"Display"} \
 	{"Shading" \
-	     {"Change shading" "coverage(run_of_colors)"} \
+	     {"Blend between end colors" "coverage(blend_colors)" "B"} \
+	     {} \
+	     {"SUBMENU" "shades" "Shadings"} \
+	     {} \
 	     {"Reverse shading" "coverage(reverse_colors)"} \
-	     {} \
              {"Select random colors" "coverage(random_colors)"} \
-	     {"Swap color swatches" "coverage(swap_color_diversity_decay)"} \
-	     {"Shade between end colors" "coverage(blend_colors)"} \
-	     {} \
-	     {"SaVi color shades" "coverage(restore_colors)"} }
+	     {"Swap color swatches" "coverage(swap_color_diversity_decay)"} }
+
+    build_Menu $coverage_name.mbar.b6.shades \
+        {"SaVi color shades" "coverage(restore_colors)"} \
+	{} \
+	{"shades of purple" "coverage(shades_colors_purple)"} \
+	{"shades of green" "coverage(shades_colors_green)"} \
+	{"shades of grey" "coverage(shades_colors_grey)"} \
+	{} \
+        {"Change shading" "coverage(run_of_colors)"}
 
     main(constellations_menu) $coverage_name.mbar.b3
 
     constellations(rendering_menu) $coverage_name.mbar.b4
 
     build_options_menu $coverage_name.mbar.b5 \
+	{"SUBMENU" map_size "Map size"} \
 	{"Show Earth map" map_flag} \
 	{} \
 	{"Show coverage" coverage_flag} \
@@ -156,48 +172,57 @@ proc coverage(build) {} {
 	{"Show satellites" tracks_flag} \
 	{"Record ground tracks" project_tracks_flag}
 
+    build_Menu $coverage_name.mbar.b5.map_size \
+	{"large Earth map" "coverage(map_large)"} \
+	{"small Earth map" "coverage(map_small)"} \
+	{} \
+        {"Custom map size..." "coverage_size(build)"}
+    
     set cmd [build_CmdFrame $coverage_name cmd]
 
-    set c "$cmd.c"
-    # canvas counts from 0
-    canvas $c -bg $COLOR(bg) -width $IM_W -height $IM_H
-    pack $c -fill x -side top
-
-    if {$coverage_display_center_longitude < 0} {
-	set offset_longitude [expr $coverage_display_center_longitude + 360]
-    } else {
-	set offset_longitude $coverage_display_center_longitude
-    }
-
-    set im_x_offset [expr 2 + ($offset_longitude * -$IM_W/360)]
-    set im_y_offset 2
-
-    set im [image create photo im_coverage -width [expr $IM_W*2] -height $IM_H]
-    $c create image [expr $IM_W + $im_x_offset] [expr $IM_H/2 + $im_y_offset] \
-	-image $im
-
-    # catch button click in map to get fisheye Lat/Long
-    bind $c <Button-1> {coverage(lat_long) %x %y}
-    bind $c <Control-Button-1> {coverage_set(lat_long) %x %y}
-
-    bind $c <Button-2> {coverage(back_step)}
-    bind $c <Button-3> {coverage(forw_step)}
-    bind $c <Shift-Button-2> {coverage(backwards)}
-    bind $c <Shift-Button-3> {coverage(forwards)}
-
+    set cmdmap [build_StdFrame $cmd map]
+    pack $cmdmap -fill x
+    # -side left actually works nicely...
+    
+    coverage(map_show)
+    
     set cmdq [build_StdFrame $cmd q]
     build_Optionslist $cmdq olist \
 	{"Show Earth map" map_flag}
     pack $cmdq.olist -side left
-    build_IPopupMenu $cmdq p0 "projected as:" \
-        coverage_projection coverage(map) {"unprojected land/sea" "unprojected" "cylindrical" "sinusoidal" "sinusoidal (90W)" "spherical" "spherical (90W)"}
+
+    set maps_list {"unprojected land/sea" \
+		   "unprojected" \
+		   "spherical" \
+		   "spherical (90W)"}
+    if {$coverage_all_projections} {
+        set maps_list {"unprojected land/sea"
+	               "unprojected" \
+	               "spherical" \
+	               "spherical (90W)" \
+                       "sinusoidal" \
+                       "sinusoidal (90W)" \
+                       "cylindrical"}
+    }
+	build_IPopupMenu $cmdq p0 "projected as:" \
+	coverage_projection coverage(map) $maps_list
+	# coverage_projection coverage(map) {"unprojected land/sea" "unprojected" "cylindrical" "sinusoidal" "sinusoidal (90W)" "spherical" "spherical (90W)"}
     pack $cmdq.p0 -side left
 
-    build_LabelEntryColumns $cmdq p1 \
+    build_IPopupMenu $cmdq p1 "in" NUM_COLORS coverage(shades) {"colors:" \
+	"1 shade" "2 shades" "3 shades" "4 shades" "5 shades" "6 shades" \
+	"7 shades" "8 shades" "9 shades" "10 shades" "11 shades" "12 shades" \
+	"13 shades" "14 shades" "15 shades" "16 shades" "17 shades" \
+        "18 shades" "19 shades" "20 shades" "21 shades" "22 shades" "23 shades" \
+	"24 shades" "25 shades" "26 shades" "27 shades" "28 shades" "29 shades"}
+    
+    pack $cmdq.p1 -side left
+    
+    build_LabelEntryColumns $cmdq p2 \
 	{text "" {"Clicked: "}} \
 	{label "" {Fisheye(clicked_coords)}}
 
-    pack $cmdq.p1 -side left
+    pack $cmdq.p2 -side right
     pack $cmdq -anchor w
 
     set cmda [build_StdFrame $cmd a]
@@ -212,72 +237,7 @@ proc coverage(build) {} {
 #	{"Record ground tracks    and project forwards" project_tracks_flag}
     pack $cmda.olist -side left
 
-    build_StdFrame $cmda ce
-    build_StdFrame $cmda.ce cf
-    label $cmda.ce.cf.0 -text "satellites in view\n(coverage diversity)" \
-	    -font $FONT(label)
-    pack $cmda.ce.cf.0 -side right -ipadx 2m -ipady 2m \
-	    -padx 1m -pady 1m
-
-    if {$NUM_COLORS != $NUM_COLORS_PREV} {
-        coverage(init_colors)
-    }
-
-    for {set i 1} {$i < $NUM_COLORS} {incr i} {
-        button $cmda.ce.cf.$i -text "$i" -font $FONT(fixed) -bg $COLDIV($i) \
-	    -activebackground $COLDIV($i) -highlightbackground $COLDIV($i) \
-	    -command "coverage(diversitycolor) $i" \
-	    -relief groove
-	pack $cmda.ce.cf.$i -expand 1 -fill x -side left -ipadx 2m -ipady 2m \
-	    -padx 1m -pady 1m
-    }
-    button $cmda.ce.cf.$NUM_COLORS -text "$NUM_COLORS+" -font $FONT(fixed) \
-	    -bg $COLDIV($NUM_COLORS) \
-	    -activebackground $COLDIV($NUM_COLORS) \
-	    -highlightbackground $COLDIV($NUM_COLORS) \
-	    -command "coverage(diversitycolor) $NUM_COLORS" \
-	    -relief groove
-    pack $cmda.ce.cf.$NUM_COLORS -expand 1 -fill x -side left -ipadx 1m -ipady 2m \
-	    -padx 1m -pady 1m
-
-    set max_colors [expr $NUM_COLORS + 1]
-    # label $cmda.ce.cf.$max_colors -text "satellites" -font $FONT(label)
-    # pack $cmda.ce.cf.$max_colors -ipady 2m -expand 1
-
-    pack $cmda.ce.cf -expand 1 -fill x -side left -ipadx 2m -ipady 2m \
-	 -padx 1m -pady 1m
-    pack $cmda.ce.cf -side top
-
-    build_StdFrame $cmda.ce cg
-    label $cmda.ce.cg.0 -text "intervals since view\n(coverage decay)" -font $FONT(label)
-    pack $cmda.ce.cg.0 -side right -ipadx 2m -ipady 2m \
-	    -padx 1m -pady 1m
-
-    for {set i 1} {$i < $NUM_COLORS} {incr i} {
-        button $cmda.ce.cg.$i -text "$i" -font $FONT(fixed) -bg $COLDEC($i) \
-	    -activebackground $COLDEC($i) -highlightbackground $COLDEC($i) \
-	    -command "coverage(decaycolor) $i" \
-	    -relief groove
-	pack $cmda.ce.cg.$i -expand 1 -fill x -side left -ipadx 2m -ipady 2m \
-	    -padx 1m -pady 1m
-    }
-    button $cmda.ce.cg.$NUM_COLORS -text "$NUM_COLORS+" -font $FONT(fixed) \
-	    -bg $COLDIV($NUM_COLORS) \
-	    -activebackground $COLDIV($NUM_COLORS) \
-	    -highlightbackground $COLDIV($NUM_COLORS) \
-	    -command "coverage(diversitycolor) $NUM_COLORS" \
-	    -relief groove
-    pack $cmda.ce.cg.$NUM_COLORS -expand 1 -fill x -side right -ipadx 1m -ipady 2m \
-	    -padx 1m -pady 1m
-
-    # label $cmda.ce.cg.$max_colors -text "intervals" -font $FONT(label)
-    # pack $cmda.ce.cg.$max_colors -ipady 2m -expand 1
-
-    pack $cmda.ce.cg -expand 1 -fill x -side left -ipadx 2m -ipady 2m \
-	 -padx 1m -pady 1m
-    pack $cmda.ce.cg -side top
-
-    pack $cmda.ce -side right -fill both
+    coverage(wells_frame)
 
     pack $cmda -fill both
 
@@ -321,7 +281,7 @@ proc coverage(build) {} {
 
     pack $cmdb.le1
 
-    pack $cmdb -expand 1
+    pack $cmdb
 
     set cmdd [build_StdFrame $cmd d]
 
@@ -331,10 +291,10 @@ proc coverage(build) {} {
 	{text "" "Time:"} \
 	{label "" {time}}
 
-    pack $cmdd.le0 -side left
-    pack $cmdd -fill both -expand 1
+    pack $cmdd.le0 -side bottom
+    pack $cmdd -fill both -side bottom -expand 1
 
-    pack $cmd -fill both -side top -expand 1
+    pack $cmd -fill both -expand 1
 
     build_Buttonbar $coverage_name bb1 \
         {"Restart" coverage(restart)} \
@@ -347,9 +307,166 @@ proc coverage(build) {} {
     set coverage_flag $coverage_flag_dismissed
     set tracks_flag $tracks_flag_dismissed
 
+    if {$NUM_COLORS_PREV == 0} {
+	coverage(init_colors)
+	set NUM_COLORS_PREV $NUM_COLORS
+    }
     coverage(update_colors)
 }
 
+proc coverage(map_show) {} {
+    global IM_W IM_H COLOR coverage_display_center_longitude
+    global im im_x_offset im_y_offset
+    
+    set c ".coverage.cmd.map.c"
+    # canvas counts from 0
+    canvas $c -bg $COLOR(bg) -width $IM_W -height $IM_H
+
+    
+    if {$coverage_display_center_longitude < 0} {
+	set offset_longitude [expr $coverage_display_center_longitude + 360]
+    } else {
+	set offset_longitude $coverage_display_center_longitude
+    }
+
+    set im_x_offset [expr 2 + ($offset_longitude * -$IM_W/360)]
+    set im_y_offset 2
+
+    set im [image create photo im_coverage -width [expr $IM_W*2] -height $IM_H]
+    $c create image [expr $IM_W + $im_x_offset] [expr $IM_H/2 + $im_y_offset] \
+	-image $im
+    pack $c -fill x -side top
+    
+    # catch button click in map to get fisheye Lat/Long
+    bind $c <Button-1> {coverage(lat_long) %x %y}
+    bind $c <Control-Button-1> {coverage_set(lat_long) %x %y}
+
+    bind $c <Button-2> {coverage(back_step)}
+    bind $c <Button-3> {coverage(forw_step)}
+    bind $c <Shift-Button-2> {coverage(backwards)}
+    bind $c <Shift-Button-3> {coverage(forwards)}
+
+}
+
+proc coverage(map_hide) {} {
+    global im
+    
+    set c ".coverage.cmd.map.c"
+    $c delete image $im
+    destroy $c
+    
+}
+
+proc coverage(map_large) {} {
+    global IM_W IM_H
+
+    if {$IM_W == 1024} return
+
+    coverage(map_hide)
+    
+    set IM_W 1024
+    set IM_H 512
+
+    satellites COVERAGE_MAP_OFF
+    satellites COVERAGE_MAP_ON
+
+    coverage(map_show)
+    coverage(update)
+}
+
+proc coverage(map_small) {} {
+    global IM_W IM_H
+
+    if {$IM_W == 600} return
+    
+    coverage(map_hide)
+    
+    set IM_W 600
+    set IM_H 300
+
+    satellites COVERAGE_MAP_OFF
+    satellites COVERAGE_MAP_ON
+
+    coverage(map_show)
+    coverage(update)
+}
+
+proc coverage(wells_frame) {} {
+    global NUM_COLORS COLDIV COLDEC FONT coverage_projection Projection sun_flag
+
+    # build_StdFrame $cmda.ce
+    set cmdace [build_StdFrame .coverage.cmd.a ce]
+    set cmdacef [build_StdFrame .coverage.cmd.a.ce cf]
+    label $cmdace.cf.0 -text "satellites in view\n(coverage diversity)" \
+	    -font $FONT(label)
+    pack $cmdace.cf.0 -side right -ipadx 2m -ipady 2m \
+	    -padx 1m -pady 1m
+
+    for {set i 1} {$i < $NUM_COLORS} {incr i} {
+        button $cmdace.cf.$i -text "$i" -font $FONT(fixed) -bg $COLDIV($i) \
+	    -activebackground $COLDIV($i) -highlightbackground $COLDIV($i) \
+	    -command "coverage(diversitycolor) $i" \
+	    -relief groove
+	pack $cmdace.cf.$i -expand 1 -fill x -side left -ipadx 2m -ipady 2m \
+	    -padx 1m -pady 1m
+    }
+    button $cmdace.cf.$NUM_COLORS -text "$NUM_COLORS+" -font $FONT(fixed) \
+	    -bg $COLDIV($NUM_COLORS) \
+	    -activebackground $COLDIV($NUM_COLORS) \
+	    -highlightbackground $COLDIV($NUM_COLORS) \
+	    -command "coverage(diversitycolor) $NUM_COLORS" \
+	    -relief groove
+    pack $cmdace.cf.$NUM_COLORS -expand 1 -fill x -side left -ipadx 1m -ipady 2m \
+	    -padx 1m -pady 1m
+
+    # set max_colors [expr $NUM_COLORS + 1]
+    # label $cmda.ce.cf.$max_colors -text "satellites" -font $FONT(label)
+    # pack $cmda.ce.cf.$max_colors -ipady 2m -expand 1
+
+    pack $cmdace.cf -expand 1 -fill x -side left -ipadx 2m -ipady 2m \
+	 -padx 1m -pady 1m
+    pack $cmdace.cf -side top
+
+    build_StdFrame $cmdace cg
+    label $cmdace.cg.0 -text "intervals since view\n(coverage decay)" -font $FONT(label)
+    pack $cmdace.cg.0 -side right -ipadx 2m -ipady 2m \
+	    -padx 1m -pady 1m
+
+    for {set i 1} {$i < $NUM_COLORS} {incr i} {
+        button $cmdace.cg.$i -text "$i" -font $FONT(fixed) -bg $COLDEC($i) \
+	    -activebackground $COLDEC($i) -highlightbackground $COLDEC($i) \
+	    -command "coverage(decaycolor) $i" \
+	    -relief groove
+	pack $cmdace.cg.$i -expand 1 -fill x -side left -ipadx 2m -ipady 2m \
+	    -padx 1m -pady 1m
+    }
+    button $cmdace.cg.$NUM_COLORS -text "$NUM_COLORS+" -font $FONT(fixed) \
+	    -bg $COLDIV($NUM_COLORS) \
+	    -activebackground $COLDIV($NUM_COLORS) \
+	    -highlightbackground $COLDIV($NUM_COLORS) \
+	    -command "coverage(diversitycolor) $NUM_COLORS" \
+	-relief groove
+
+    if {$coverage_projection == $Projection(unprojected_mask)} {
+	coverage(labels_show_land_sea)
+    } elseif {$sun_flag} {
+	coverage(labels_show_sunlight)
+    }
+
+    pack $cmdace.cg.$NUM_COLORS -expand 1 -fill x -side right -ipadx 1m -ipady 2m \
+	    -padx 1m -pady 1m
+
+    # label $cmda.ce.cg.$max_colors -text "intervals" -font $FONT(label)
+    # pack $cmda.ce.cg.$max_colors -ipady 2m -expand 1
+
+    pack $cmdace.cg -expand 1 -fill x -side left -ipadx 2m -ipady 2m \
+	 -padx 1m -pady 1m
+    pack $cmdace.cg -side top
+
+    pack $cmdace -side right -fill both
+
+}
+
 proc constellations(rendering_menu) {submenu} {
     global geomview_module
 
@@ -379,7 +496,7 @@ proc coverage(back_step) {} {
 proc coverage(forwards) {} {
     global COLOR playbar
 
-    if {([winfo exists .coverage])} {
+    if [winfo exists .coverage] {
 	.coverage.bb1.b3 configure -bg $COLOR(bg) -highlightbackground $COLOR(bg)
 	.coverage.bb1.b4 configure -bg $COLOR(bg) -highlightbackground $COLOR(bg)
 	.coverage.bb1.b5 configure -bg $COLOR(sbg) -highlightbackground $COLOR(sbg)
@@ -395,7 +512,7 @@ proc coverage(forwards) {} {
 proc coverage(backwards) {} {
     global COLOR playbar
 
-    if {([winfo exists .coverage])} {
+    if [winfo exists .coverage] {
 	.coverage.bb1.b3 configure -bg $COLOR(bg) -highlightbackground $COLOR(bg)
 	.coverage.bb1.b4 configure -bg $COLOR(sbg) -highlightbackground $COLOR(sbg)
 	.coverage.bb1.b5 configure -bg $COLOR(bg) -highlightbackground $COLOR(bg)
@@ -411,7 +528,7 @@ proc coverage(backwards) {} {
 proc coverage(stop) {} {
     global COLOR playbar
 
-    if {([winfo exists .coverage])} {
+    if [winfo exists .coverage] {
 	.coverage.bb1.b3 configure -bg $COLOR(sbg) -highlightbackground $COLOR(sbg)
 	.coverage.bb1.b4 configure -bg $COLOR(bg) -highlightbackground $COLOR(bg)
 	.coverage.bb1.b5 configure -bg $COLOR(bg) -highlightbackground $COLOR(bg)
@@ -436,7 +553,7 @@ proc coverage(set_angle) v {
 }
 
 proc coverage(update_angle) {} {
-    global coverage_flag coverage_angle cones_flag footprints_flag
+    global coverage_flag coverage_angle
 
     set coverage_angle [expr abs($coverage_angle)]
     if {$coverage_angle > 90} {
@@ -479,6 +596,57 @@ proc coverage(init_colors) {} {
     coverage(blend_color_values) 1
 }
 
+proc coverage(shades_colors_grey) {} {
+    global NUM_COLORS
+    global DIV DEC
+
+    set DIV(0) [expr 0xffffff]
+    set DIV(1) [expr 0xdddddd]
+    set DIV($NUM_COLORS) [expr 0x333333]
+
+    set DEC(0) [expr 0xffffff]
+    set DEC(1) [expr 0x0000ff]
+    set DEC($NUM_COLORS) [expr 0x0000ff]
+
+    coverage(blend_color_values) 1
+
+    coverage(update_colors)
+}
+
+proc coverage(shades_colors_green) {} {
+    global NUM_COLORS
+    global DIV DEC
+
+    set DIV(0) [expr 0xffffff]
+    set DIV(1) [expr 0x00ff00]
+    set DIV($NUM_COLORS) [expr 0x003300]
+
+    set DEC(0) [expr 0xffffff]
+    set DEC(1) [expr 0x0000ff]
+    set DEC($NUM_COLORS) [expr 0x0000ff]
+
+    coverage(blend_color_values) 1
+
+    coverage(update_colors)
+}
+
+proc coverage(shades_colors_purple) {} {
+    global NUM_COLORS
+    global DIV DEC
+
+    set DIV(0) [expr 0xffffff]
+    set DIV(1) [expr 0xff00ff]
+    set DIV($NUM_COLORS) [expr 0x330033]
+
+    set DEC(0) [expr 0xffffff]
+    set DEC(1) [expr 0x0000ff]
+    set DEC($NUM_COLORS) [expr 0x00008f]
+
+    coverage(blend_color_values) 1
+
+    coverage(update_colors)
+}
+
 proc coverage(init_coldiv_coldec) {} {
     global COLDIV COLDEC
 
@@ -504,6 +672,16 @@ proc coverage(init_coldiv_coldec) {} {
     set COLDIV(17) #ffffff
     set COLDIV(18) #ffffff
     set COLDIV(19) #ffffff
+    set COLDIV(20) #ffffff
+    set COLDIV(21) #ffffff
+    set COLDIV(22) #ffffff
+    set COLDIV(23) #ffffff
+    set COLDIV(24) #ffffff
+    set COLDIV(25) #ffffff
+    set COLDIV(26) #ffffff
+    set COLDIV(27) #ffffff
+    set COLDIV(28) #ffffff
+    set COLDIV(29) #ffffff
 
     set COLDEC(0) #ffffff
     set COLDEC(1) #ffffff
@@ -525,6 +703,16 @@ proc coverage(init_coldiv_coldec) {} {
     set COLDEC(17) #ffffff
     set COLDEC(18) #ffffff
     set COLDEC(19) #ffffff
+    set COLDEC(20) #ffffff
+    set COLDEC(21) #ffffff
+    set COLDEC(22) #ffffff
+    set COLDEC(23) #ffffff
+    set COLDEC(24) #ffffff
+    set COLDEC(25) #ffffff
+    set COLDEC(26) #ffffff
+    set COLDEC(27) #ffffff
+    set COLDEC(28) #ffffff
+    set COLDEC(29) #ffffff
 }
 
 proc coverage(labels_show_land_sea) {} {
@@ -989,18 +1177,28 @@ proc coverage(save_map) {} {
 
     satellites COVERAGE_SAVE_MAP "$filename"
 
-    set gzip gzip
+    save(gzip_file) "$filename"
 
-    if {[catch {eval exec $gzip -9 "$filename"}]} {
-        puts stderr "\nSaVi: saved map as raw ppm to $filename"
-	puts stderr "      failed to compress map with $gzip."
-        return
-    }
-    puts stderr "\nSaVi: saved $gzip-compressed map to $filename.gz"
+}
+
+proc coverage(save_plot) {filename} {
+    global Projection coverage_projection im IM_W IM_H
+
+    if {"$filename" == ""} return
+
+    if {($coverage_projection == $Projection(unprojected)) || \
+	($coverage_projection == $Projection(unprojected_mask))} {
+	# could use gif, but Xfig needs netpbm to convert gif, has display issues.
+        $im write "$filename.ppm" -format ppm -from 0 0 $IM_W $IM_H
+        puts stderr "\nSaVi: unprojected map background written to $filename.ppm"
+	save(gzip_file) "$filename.ppm"
+   } else {
+	puts stderr "\nSaVi: can only save unprojected maps as plot script backgrounds!"
+   }
 }
 
 proc coverage(dismiss) {} {
-    global NUM_COLORS NUM_COLORS_PREV coverage_flag tracks_flag \
+    global coverage_flag tracks_flag \
 	   coverage_flag_dismissed tracks_flag_dismissed
 
     set coverage_flag_dismissed $coverage_flag
@@ -1010,10 +1208,6 @@ proc coverage(dismiss) {} {
     set coverage_flag 0
     set tracks_flag 0
 
-    # reset colours to force being asked again.
-    set NUM_COLORS_PREV $NUM_COLORS
-    set NUM_COLORS 0
-
     destroy .coverage
 }
 
@@ -1053,7 +1247,7 @@ proc coverage(update) {} {
 
 proc coverage(lat_long) {x y} {
     global Fisheye coverage_projection IM_W IM_H im_x_offset im_y_offset \
-	   Longitude_Center_Line PI coverage_display_center_longitude Projection
+	   Longitude_Center_Line PI Projection
 
     set x [expr $x-$im_x_offset]
     set y [expr $y-$im_y_offset]
@@ -1230,7 +1424,7 @@ proc coverage_set(lat_long) {x y} {
 }
 
 proc coverage(foot) {} {
-    global coverage_angle coverage_flag
+    global coverage_angle
 
     if {$coverage_angle > 90} {
       set coverage_angle 90
@@ -1286,8 +1480,29 @@ proc coverage(map) {} {
     set last_coverage_projection $coverage_projection
     coverage(update)
 
-        # this is a hack to reset Earth while dynamic texturemapping,
+    # this is a hack to reset Earth while dynamic texturemapping,
     # if we move from cylindrical/unprojected projections supporting
     # texturemapping to other projections that don't.
     geomview(update_texture)
 }
+
+proc coverage(shades) {} {
+    global NUM_COLORS NUM_COLORS_PREV DIV DEC
+
+    if {$NUM_COLORS < 1} {
+	set NUM_COLORS $NUM_COLORS_PREV
+	return
+    }
+    
+    if {$NUM_COLORS > $NUM_COLORS_PREV} {
+        for {set i [expr $NUM_COLORS_PREV+1]} {$i <= $NUM_COLORS} {incr i} {
+            set DIV($i) $DIV($NUM_COLORS_PREV)
+            set DEC($i) $DEC($NUM_COLORS_PREV)
+        }
+    }
+    set NUM_COLORS_PREV $NUM_COLORS
+
+    destroy .coverage.cmd.a.ce
+    coverage(wells_frame)
+    coverage(update_colors)
+}
