@@ -19,10 +19,10 @@
 ######################################################
 #
 # details.tcl
-# $Id: details.tcl,v 1.20 2017/01/02 06:11:33 lloydwood Exp $
+# $Id: details.tcl 161 2020-02-06 10:56:52Z lloydwood $
 
 proc details(build) {} {
-    global last_filename source_comments comments_text comments_file details_source
+    global last_filename source_comments comments_text comments_file details_source env
 
     if {[eval window(raise) details]} return
 
@@ -46,8 +46,10 @@ proc details(build) {} {
 
     set comments_text [build_Scrollingtext $cmd text 50 10]
 
-    $comments_text insert end "\nThis window describes details of the currently loaded constellation. Further details are in the constellation scripts in SaVi's data/ directory. This window can be closed, and later reopened from the Help menu.\n\n"
+    set SAVI $env(SAVI)
+
     $comments_text insert end $source_comments
+    $comments_text insert end "\n\n\nThis window describes details of the currently loaded constellation.  This window can be closed, and later reopened from the Help menu.\n\nFurther details are in the constellation scripts that are present in the $SAVI/data directory. View a script by pressing the View Source... button.\n\n"
 
     pack $cmd.text -side left -anchor w -ipadx 15m -ipady 2m
 
@@ -59,12 +61,6 @@ proc details(dismiss) {} {
 }
 
 proc details(rebuild) {} {
-    global source_comments last_filename comments_text comments_file
-
-    if {[eval window(raise) details]} {
-	$comments_file.label configure -text "Comments on $last_filename"
-
-        $comments_text delete 1.0 end
-	$comments_text insert end $source_comments
-    }
+	details(dismiss)
+	details(build)
 }
