@@ -20,7 +20,7 @@
 #
 # equator.tcl
 #
-# $Id: equator.tcl,v 1.7 2017/01/02 06:11:33 lloydwood Exp $
+# $Id: equator.tcl 195 2023-04-10 04:24:20Z lloydwood $
 
 set previous_parallels_angle 0
 
@@ -38,17 +38,33 @@ proc equator(create) {} {
 
     # lots of satellites to mark the geostationary or other rings.
 
-    set MU $params(Mu)
-
     # markers every degree of longitude
     set NUM_PLANES 360
 
-    # setup orbital elements
-    # need to compute radius in gravitational field with MU instead!
-    set a [expr 35786.1+$params(Radius)]
-    set omega 0.0
-    set T 0
+    # setup orbital elements; this quick hack has been upgraded
+    # set a [expr 35786.1+$params(Radius)]
 
+    set MU $params(Mu)
+
+    # stationary radius is cube root of (Mu T^2 / 4 pi^2) where
+    # G is gravitational constant, m is mass in kg/s; Gm = MU
+    # T is period of rotation in seconds. Omega is radians/second,
+    # two PI radians in a circle.
+    set OM $params(Omega)
+
+
+    # the 2PIs cancel out, but we show in comments for clarity.
+    # Must force floating point in Tcl by stating .0
+    set cuberoot [expr 1.0/3]
+
+    # set T [expr 2 * $PI / $params(Omega)] 
+    # set a [expr { 0.0 + pow(($MU * $T*$T/4/$PI/$PI),$cuberoot) } ]
+
+    set a [expr { 0.0 + pow(($MU / $OM / $OM),$cuberoot) } ]
+
+    set omega 0.0
+    set T 0.0
+	   
     # not yet requiring geomview.
     satellites GV_BEGIN
 
