@@ -20,7 +20,7 @@
 #
 # fisheye.tcl
 #
-# $Id: fisheye.tcl,v 1.71 2017/07/02 11:07:11 lloydwood Exp $
+# $Id: fisheye.tcl 179 2020-05-27 05:33:37Z lloydwood $
 
 proc fisheye(init) {} {
     global fisheye_flag fisheye_reverse_view_flag fisheye_names_flag fisheye_numbers_flag \
@@ -56,9 +56,9 @@ proc fisheye(init) {} {
 }
 
 proc fisheye(build) {} {
-    global Fisheye fisheye_flag fisheye_flag_dismissed fisheye_names_flag
+    global Fisheye fisheye_names_flag
     global fisheye_times_flag fisheye_numbers_flag fisheye_viewpoint_flag
-    global plane_flag parallels_angle
+    global plane_flag
 
     if {[eval window(raise) fisheye]} return
 
@@ -107,50 +107,116 @@ proc fisheye(build) {} {
 	     {"Equator (0,0)" "fisheye(set_location) 0 0 0 0 {Equator (0 , 0)}"} \
 	     {"North Pole" "fisheye(set_location) 90 0 0 0 {North Pole}"} \
 	     {"South Pole" "fisheye(set_location) -90 0 0 0 {South Pole} "} \
+	     {"SUBMENU" "africa" "Africa"} \
+	     {"SUBMENU" "asia" "Asia"} \
+	     {"SUBMENU" "antarctica" "Antarctica"} \
+	     {"SUBMENU" "australasia" "Australasia"} \
+	     {"SUBMENU" "europe" "Europe"} \
+	     {"SUBMENU" "northamerica" "North America"} \
+	     {"SUBMENU" "southamerica" "South America"} \
 	     {} \
-	     {"Adelaide, Australia" "fisheye(set_location) -34 55 138 36 {Adelaide, Australia}"} \
-	     {"Algiers, Algeria" "fisheye(set_location) 36 50 3 0 {Algiers, Algeria}"} \
-	     {"Amsterdam, Netherlands" "fisheye(set_location) 52 22 4 53 {Amsterdam, Netherlands}"} \
-	     {"Anchorage, Alaska" "fisheye(set_location) 61 13 -149 54 {Anchorage, Alaska}"} \
-	     {"Ankara, Turkey" "fisheye(set_location) 39 55 32 55 {Ankara, Turkey}"} \
-	     {"Athens, Greece" "fisheye(set_location) 37 58 23 43 {Athens, Greece}"} \
-	     {"Auckland, New Zealand" "fisheye(set_location) -36 52 174 45 {Auckland, New Zealand}"} \
-	     {"Bangkok, Thailand" "fisheye(set_location) 13 45 100 30 {Bangkok, Thailand}"} \
-	     {"Beijing, China" "fisheye(set_location) 39 55 116 25 {Beijing, China}"} \
-	     {"Berlin, Germany" "fisheye(set_location) 52 30 13 25 {Berlin, Germany}"} \
-	     {"Bombay, India" "fisheye(set_location) 19 0 72 48 {Bombay, India}"} \
-             {"Brisbane, Australia" "fisheye(set_location) -27 28 153 0 {Brisbane, Australia}"} \
-	     {"Brussels, Belgium" "fisheye(set_location) 50 52 4 22 {Brussels, Belgium}"} \
-	     {"Buenos Aires, Argentina" "fisheye(set_location) -34 35 -58 22 {Buenos Aires, Argentina}"} \
-	     {"Canberra, Australia" "fisheye(set_location) -35 18 149 7 {Canberra, Australia}"} \
-	     {"Copenhagen, Denmark" "fisheye(set_location) 55 40 12 34 {Copenhagen, Denmark}"} \
-	     {"Dublin, Eire" "fisheye(set_location) 53 20 -6 15 {Dublin, Eire}"} \
-	     {"Lima, Peru" "fisheye(set_location) -12 0 -77 2 {Lima, Peru}"} \
-	     {"Lisbon, Portugal" "fisheye(set_location) 38 44 -9 9 {Lisbon, Portugal}"} \
-	     {"London, UK" "fisheye(set_location) 51 32 0 -5 {London, UK}"} \
-	     {"Madrid, Spain" "fisheye(set_location) 40 26 -3 42 {Madrid, Spain}"} \
-	     {"Mecca, Saudi Arabia" "fisheye(set_location) 21 29 39 45 {Mecca, Saudi Arabia}"} \
-	     {"Melbourne, Australia" "fisheye(set_location) -37 47 144 58 {Melbourne, Australia}"} \
-             {"Miami, Florida" "fisheye(set_location) 25 47 -80 13 {Miami, Florida}"} \
-	     {"Moscow, Russia" "fisheye(set_location) 55 45 37 36 {Moscow, Russia}"} \
-	     {"New York, USA" "fisheye(set_location) 40 47 -73 58 {New York, USA}"} \
-	     {"Oslo, Norway" "fisheye(set_location) 59 57 10 42 {Oslo, Norway}"} \
-	     {"Paris, France" "fisheye(set_location) 48 48 2 20 {Paris, France}"} \
-	     {"Perth, Australia" "fisheye(set_location) -31 57 115 51 {Perth, Australia}"} \
-	     {"Port Moresby, Papua New Guinea" "fisheye(set_location) -9 25 147 17 {Port Moresby, Papua New Guinea}"} \
-	     {"Quito, Ecuador" "fisheye(set_location) 0 -14 -78 30 {Quito, Ecuador}"} \
-	     {"San Francisco, USA" "fisheye(set_location) 37 47 -122 26 {San Francisco, USA}"} \
-	     {"Reykjavik, Iceland" "fisheye(set_location) 64 4 -21 58 {Reykjavik, Iceland}"} \
-	     {"Rio de Janeiro, Brazil" "fisheye(set_location) -22 57 -43 12 {Rio de Janeiro, Brazil}"} \
-	     {"Rome, Italy" "fisheye(set_location) 41 54 12 27 {Rome, Italy}"} \
-	     {"Singapore" "fisheye(set_location) 1 14 103 55 {Singapore}"} \
-	     {"Sydney, Australia" "fisheye(set_location) -34 0 151 0 {Sydney, Australia}"} \
-	     {"Toronto, Canada" "fisheye(set_location) 43 40 -79 24 {Toronto, Canada}"} \
-	     {"Tokyo, Japan" "fisheye(set_location) 35 40 139 45 {Tokyo, Japan}"} \
-	     {"Vancouver, Canada" "fisheye(set_location) 49 13 -123 6 {Vancouver, Canada}"} \
-	     {"Vienna, Austria" "fisheye(set_location) 48 14 16 20 {Vienna, Austria}"} \
-	     {"Washington DC, USA" "fisheye(set_location) 38 53 -77 02 {Washington DC, USA}"} \
-	     {"Wellington, New Zealand" "fisheye(set_location) -41 17 174 47 {Wellington, New Zealand}"} }
+	     {"SUBMENU" "pacific" "Pacific Ocean"} \
+	     {"SUBMENU" "atlantic" "Atlantic Ocean"} \
+	     {"SUBMENU" "indian" "Indian Ocean"} \
+	     {"SUBMENU" "med" "Mediterranean Sean"} }
+    
+    build_Menu $fisheye_name.mbar.b6.africa \
+	{"Algiers, Algeria" "fisheye(set_location) 36 50 3 0 {Algiers, Algeria}"} \
+        {"Cairo, Egypt" "fisheye(set_location) 30 3.6 31 13.8   {Cairo, Egypt}"} \
+        {"Casablanca, Morocco" "fisheye(set_location) 33 66 -7 37.2  {Casablanca, Morocco}"} \
+        {"Dakar, Senegal" "fisheye(set_location) 14 43.8 -17 27  {Dakar, Senegal}"} \
+        {"Lagos, Nigeria" "fisheye(set_location) 6 27 3 24  {Lagos, Nigeria}"} \
+	{"Addis Ababa, Ethiopia" "fisheye(set_location) 9 0.18 38 43.8 {Addis Ababa, Ethiopia}"} \
+	{"Nairobi, Kenya" "fisheye(set_location) -1 17.4 36 48.6 {Nairobi, Kenya}"} \
+	{"Harare, Zimbabwe" "fisheye(set_location) -17 49.8 31 3 {Harare, Zimbabwe}"} \
+        {"Johannesburg, South Africa" "fisheye(set_location) -26 12 28 2.4 {Johannesburg, Soth Africa}"} \
+	{"Cape Town, South Africa" "fisheye(set_location) -33 55.2 18 25.2 {Cape Town, Sourh Africa}"} 
+
+    build_Menu $fisheye_name.mbar.b6.antarctica \
+	{"Casey Station" "fisheye(set_location) -66 17 119 31.5 {Casey Station}"} \
+	{"Mawson Station" "fisheye(set_location) -67 36 62 52.38 {Mawson}"} \
+	{"McMurdo Station" "fisheye(set_location) -77 51 166 40 {McMurdo Station, Antarctica}"} \
+	{"Vostok Station" "fisheye(set_location) -78 28 106 50.25 {Vostok Station}"}
+    
+    build_Menu $fisheye_name.mbar.b6.asia \
+        {"Ankara, Turkey" "fisheye(set_location) 39 55 32 55 {Ankara, Turkey}"} \
+	{"Bombay, India" "fisheye(set_location) 19 0 72 48 {Bombay, India}"} \
+	{"Bangkok, Thailand" "fisheye(set_location) 13 45 100 30 {Bangkok, Thailand}"} \
+        {"Beijing, China" "fisheye(set_location) 39 55 116 25 {Beijing, China}"} \
+        {"Mecca, Saudi Arabia" "fisheye(set_location) 21 29 39 45 {Mecca, Saudi Arabia}"} \
+	{"Port Moresby, Papua New Guinea" "fisheye(set_location) -9 25 147 17 {Port Moresby, Papua New Guinea}"} \
+	{"Singapore" "fisheye(set_location) 1 14 103 55 {Singapore}"} \
+	{"Tokyo, Japan" "fisheye(set_location) 35 40 139 45 {Tokyo, Japan}"}
+
+        build_Menu $fisheye_name.mbar.b6.australasia \
+	{"Adelaide, Australia" "fisheye(set_location) -34 55 138 36 {Adelaide, Australia}"} \
+	{"Brisbane, Australia" "fisheye(set_location) -27 28 153 0 {Brisbane, Australia}"} \
+	{"Canberra, Australia" "fisheye(set_location) -35 18 149 7 {Canberra, Australia}"} \
+	{"Melbourne, Australia" "fisheye(set_location) -37 47 144 58 {Melbourne, Australia}"} \
+        {"Perth, Australia" "fisheye(set_location) -31 57 115 51 {Perth, Australia}"} \
+	{"Sydney, Australia" "fisheye(set_location) -34 0 151 0 {Sydney, Australia}"} \
+    	{"Auckland, New Zealand" "fisheye(set_location) -36 52 174 45 {Auckland, New Zealand}"} \
+        {"Wellington, New Zealand" "fisheye(set_location) -41 17 174 47 {Wellington, New Zealand}"}
+
+    # europe
+    build_Menu $fisheye_name.mbar.b6.europe \
+	{"Amsterdam, Netherlands" "fisheye(set_location) 52 22 4 53 {Amsterdam, Netherlands}"} \
+	{"Athens, Greece" "fisheye(set_location) 37 58 23 43 {Athens, Greece}"} \
+        {"Berlin, Germany" "fisheye(set_location) 52 30 13 25 {Berlin, Germany}"} \
+	{"Brussels, Belgium" "fisheye(set_location) 50 52 4 22 {Brussels, Belgium}"} \
+	{"Copenhagen, Denmark" "fisheye(set_location) 55 40 12 34 {Copenhagen, Denmark}"} \
+      	{"Dublin, Eire" "fisheye(set_location) 53 20 -6 15 {Dublin, Eire}"} \
+        {"Lisbon, Portugal" "fisheye(set_location) 38 44 -9 9 {Lisbon, Portugal}"} \
+        {"London, UK" "fisheye(set_location) 51 32 0 -5 {London, UK}"} \
+	{"Madrid, Spain" "fisheye(set_location) 40 26 -3 42 {Madrid, Spain}"} \
+	{"Moscow, Russia" "fisheye(set_location) 55 45 37 36 {Moscow, Russia}"} \
+	{"Reykjavik, Iceland" "fisheye(set_location) 64 4 -21 58 {Reykjavik, Iceland}"} \
+	{"Rome, Italy" "fisheye(set_location) 41 54 12 27 {Rome, Italy}"} \
+	{"Oslo, Norway" "fisheye(set_location) 59 57 10 42 {Oslo, Norway}"} \
+	{"Paris, France" "fisheye(set_location) 48 48 2 20 {Paris, France}"} \
+        {"Vienna, Austria" "fisheye(set_location) 48 14 16 20 {Vienna, Austria}"}
+    
+    build_Menu $fisheye_name.mbar.b6.northamerica \
+	{"Anchorage, Alaska, USA" "fisheye(set_location) 61 13 -149 54 {Anchorage, Alaska}"} \
+	{"Miami, Florida, USA" "fisheye(set_location) 25 47 -80 13 {Miami, Florida}"} \
+	{"New York, USA" "fisheye(set_location) 40 47 -73 58 {New York, USA}"} \
+	{"San Francisco, California, USA" "fisheye(set_location) 37 47 -122 26 {San Francisco, USA}"} \
+        {"Toronto, Canada" "fisheye(set_location) 43 40 -79 24 {Toronto, Canada}"} \
+	{"Vancouver, Canada" "fisheye(set_location) 49 13 -123 6 {Vancouver, Canada}"} \
+	{"Washington DC, USA" "fisheye(set_location) 38 53 -77 02 {Washington DC, USA}"}
+
+    
+    build_Menu $fisheye_name.mbar.b6.southamerica \
+        {"Buenos Aires, Argentina" "fisheye(set_location) -34 35 -58 22 {Buenos Aires, Argentina}"} \
+	{"Lima, Peru" "fisheye(set_location) -12 0 -77 2 {Lima, Peru}"} \
+        {"Quito, Ecuador" "fisheye(set_location) 0 -14 -78 30 {Quito, Ecuador}"} \
+	{"Rio de Janeiro, Brazil" "fisheye(set_location) -22 57 -43 12 {Rio de Janeiro, Brazil}"}
+
+    build_Menu $fisheye_name.mbar.b6.pacific \
+	{"Honiara, Solomon Islands" "fisheye(set_location) -9 26 159 57 {Honiara, Solomon Islands}"} \
+	{"Honolulu, Hawaii" "fisheye(set_location) 21 18 -157 51 {Honolulu, Hawaii}"} \
+	{"Suva, Fiji" "fisheye(set_location) -18 8 178 26 {Suva, Fiji}"} \
+	{"Tarawa, Kiribati" "fisheye(set_location) 1 25 173 2 {Tarawa, Kiribati}"} \
+	{"Apia, Samoa" "fisheye(set_location) -13 50 171 45 {Apia, Samoa}"} \
+	{"Nuku'alofa, Tonga" "fisheye(set_location) -21 8 175 12 {Nuku'alofa, Tonga}"} \
+    	{"Rarotonga, Cook Islands" "fisheye(set_location) -21 14 -159 47 {Rarotonga, Cook Islands}"}
+
+    build_Menu $fisheye_name.mbar.b6.atlantic \
+	{"Nuuk, Greenland" "fisheye(set_location) 64 11 -51 45 {Nuuk, Greenland}" } \
+	{"Reykjavik, Iceland" "fisheye(set_location) 64 9 -21 57 {Reykjavik, Iceland}"} \
+	{"Horta, Azores" "fisheye(set_location) 38 32 -28 38 {Horta, Azores}"} \
+	{"Stanley, Falklands" "fisheye(set_location) -51 41 -57 51 {Stanley, Falklands}"}
+
+        build_Menu $fisheye_name.mbar.b6.indian \
+	{"Colombo, Sri Lanka" "fisheye(set_location) 6 55 79 50 {Colombo, Sri Lanka}"} \
+	{"Male, Maldives" "fisheye(set_location) 4 10 73 30 {Male, Maldives}"} \
+	{"Antananarivo, Madagascar" "fisheye(set_location) -18 55 47 31 {Antananarivo, Madagascar}"} \
+	{"Port Louis, Mauritius" "fisheye(set_location) -20 9 57 30 {Port Louis, Mauritius}"} \
+	{"Victoria, Seychelles" "fisheye(set_location) -4 35 55 40 {Victoria, Seychelles}"}
+
+        build_Menu $fisheye_name.mbar.b6.med \
+	{"Gibraltar" "fisheye(set_location) 36 11 -5 22 {Gibraltar}"} \
+	{"Nicosia, Cyprus" "fisheye(set_location) 35 10 33 22 {Nicosia, Cyprus}"}
 
     main(constellations_menu) $fisheye_name.mbar.b3
     main(rendering_menu) $fisheye_name.mbar.b4
@@ -193,21 +259,16 @@ proc fisheye(build) {} {
 	{"Time in view" fisheye_times_flag} \
 	{"Stationary arc" plane_flag}
 
+    set cmdll [build_StdFrame $cmd ll]
+    pack $cmdll
+    
     set cmdb [build_StdFrame $cmd b]
 
-    build_LabelEntryColumns $cmdb le2 \
-        {text "" "Parallels"} \
-        {dentry "" {parallels_angle}} \
-	{text "" "degrees"}
-
-
     build_LabelEntryColumns $cmdb le3 \
         {text "" "Coverage"} \
         {dentry "" {coverage_angle}} \
 	{text "" "degrees"}
 
-    bind $cmdb.le2.c1.0 <Return> equator(update_angle)
-    bind $cmdb.le2.c1.0 <Tab> equator(update_angle)
     bind $cmdb.le3.c1.0 <Return> coverage(update_angle)
     bind $cmdb.le3.c1.0 <Tab> coverage(update_angle)
 
@@ -225,7 +286,7 @@ proc fisheye(build) {} {
     bind $cmdq.le0.c2.0 <Return> fisheye(apply)
     bind $cmdq.le0.c2.1 <Return> fisheye(apply)
 
-    pack $cmdq -side bottom -fill x
+    pack $cmdq -side bottom -fill both
 
     pack $cmd -fill both -expand 1
 
@@ -250,7 +311,7 @@ proc fisheye(dismiss) {} {
 }
 
 proc fisheye(draw) {} {
-    global FS_D coverage_angle
+    global FS_D
 
     # initialize display
 
@@ -258,22 +319,34 @@ proc fisheye(draw) {} {
     if {[eval winfo exists $p] == 0} return
 
     set adjust 2
+    set size_threshold_small 175
+    set size_threshold_large 350
 
     set d [expr $FS_D - $adjust]
 
+    set color_dark "black"
+    set color_light "grey90"
+
+    if {$d < $size_threshold_large} {
+        set ring_color $color_light
+    } else {
+	set ring_color $color_dark
+    }
+
     set x_start [expr double($adjust)]
     set y_end [expr double($d - $x_start)]
+
     $p create oval $x_start $x_start $y_end $y_end -fill white -width 1 -tags disk
 
     # 30 degrees circle
     set x_start [expr $d / 6 + $adjust]
     set y_end [expr $d - $x_start]
-    $p create oval $x_start $x_start $y_end $y_end -outline black -width 1 -tags disk
+    $p create oval $x_start $x_start $y_end $y_end -outline $ring_color -width 1 -tags disk
 
     # 60 degrees circle
     set x_start [expr $d / 3 + $adjust]
     set y_end [expr $d - $x_start]
-    $p create oval $x_start $x_start $y_end $y_end -outline black -width 1 -tags disk
+    $p create oval $x_start $x_start $y_end $y_end -outline $ring_color -width 1 -tags disk
 
 
     # centre point
@@ -282,85 +355,107 @@ proc fisheye(draw) {} {
     $p create rectangle $r $r $r1 $r1 -outline black -width 1 -tags disk
 
     # if canvas is too small, don't draw extra circles.
-    if {$d < 175} return;
+    if {$d < $size_threshold_small} return;
 
     # 15 degrees circle
     set x_start [expr $d / 12 + $adjust]
     set y_end [expr $d - $x_start]
-    $p create oval $x_start $x_start $y_end $y_end -outline grey50 -width 1 -tags disk
+    $p create oval $x_start $x_start $y_end $y_end -outline $ring_color -width 1 -tags disk
 
     # 45 degrees circle
     set x_start [expr $d / 4 + $adjust]
     set y_end [expr $d - $x_start]
-    $p create oval $x_start $x_start $y_end $y_end -outline grey50 -width 1 -tags disk
+    $p create oval $x_start $x_start $y_end $y_end -outline $ring_color -width 1 -tags disk
 
     # 75 degrees circle
     set x_start [expr $d * 5/12 + $adjust]
     set y_end [expr $d - $x_start]
-    $p create oval $x_start $x_start $y_end $y_end -outline grey50 -width 1 -tags disk
+    $p create oval $x_start $x_start $y_end $y_end -outline $ring_color -width 1 -tags disk
 
     # draw more circles on big canvas.
-    if {$d < 350} return;
+    if {$d < $size_threshold_large} return;
 
     # 5 degrees circle
     set x_start [expr $d / 36 + $adjust]
     set y_end [expr $d - $x_start]
-    $p create oval $x_start $x_start $y_end $y_end -outline grey90 -width 1 -tags disk
+    $p create oval $x_start $x_start $y_end $y_end -outline $color_light -width 1 -tags disk
 
     # 10 degrees circle
     set x_start [expr $d / 18 + $adjust]
     set y_end [expr $d - $x_start]
-    $p create oval $x_start $x_start $y_end $y_end -outline grey90 -width 1 -tags disk
+    $p create oval $x_start $x_start $y_end $y_end -outline $color_light -width 1 -tags disk
 
     # 20 degrees circle
     set x_start [expr $d / 9 + $adjust]
     set y_end [expr $d - $x_start]
-    $p create oval $x_start $x_start $y_end $y_end -outline grey90 -width 1 -tags disk
+    $p create oval $x_start $x_start $y_end $y_end -outline $color_light -width 1 -tags disk
 
     # 25 degrees circle
     set x_start [expr $d / 7.2 + $adjust]
     set y_end [expr $d - $x_start]
-    $p create oval $x_start $x_start $y_end $y_end -outline grey90 -width 1 -tags disk
+    $p create oval $x_start $x_start $y_end $y_end -outline $color_light -width 1 -tags disk
 
     # 35 degrees circle
     set x_start [expr $d / 5.1429 + $adjust]
     set y_end [expr $d - $x_start]
-    $p create oval $x_start $x_start $y_end $y_end -outline grey90 -width 1 -tags disk
+    $p create oval $x_start $x_start $y_end $y_end -outline $color_light -width 1 -tags disk
 
     # 40 degrees circle
     set x_start [expr $d / 4.5 + $adjust]
     set y_end [expr $d - $x_start]
-    $p create oval $x_start $x_start $y_end $y_end -outline grey90 -width 1 -tags disk
+    $p create oval $x_start $x_start $y_end $y_end -outline $color_light -width 1 -tags disk
 
     # 50 degrees circle
     set x_start [expr $d / 3.6 + $adjust]
     set y_end [expr $d - $x_start]
-    $p create oval $x_start $x_start $y_end $y_end -outline grey90 -width 1 -tags disk
+    $p create oval $x_start $x_start $y_end $y_end -outline $color_light -width 1 -tags disk
 
     # 55 degrees circle
     set x_start [expr $d / 3.273 + $adjust]
     set y_end [expr $d - $x_start]
-    $p create oval $x_start $x_start $y_end $y_end -outline grey90 -width 1 -tags disk
+    $p create oval $x_start $x_start $y_end $y_end -outline $color_light -width 1 -tags disk
 
     # 65 degrees circle
     set x_start [expr $d / 2.77 + $adjust]
     set y_end [expr $d - $x_start]
-    $p create oval $x_start $x_start $y_end $y_end -outline grey90 -width 1 -tags disk
+    $p create oval $x_start $x_start $y_end $y_end -outline $color_light -width 1 -tags disk
 
     # 70 degrees circle
     set x_start [expr $d / 2.57 + $adjust]
     set y_end [expr $d - $x_start]
-    $p create oval $x_start $x_start $y_end $y_end -outline grey90 -width 1 -tags disk
+    $p create oval $x_start $x_start $y_end $y_end -outline $color_light -width 1 -tags disk
 
     # 80 degrees circle
     set x_start [expr $d / 2.25 + $adjust]
     set y_end [expr $d - $x_start]
-    $p create oval $x_start $x_start $y_end $y_end -outline grey90 -width 1 -tags disk
+    $p create oval $x_start $x_start $y_end $y_end -outline $color_light -width 1 -tags disk
 
     # 85 degrees circle
     set x_start [expr $d / 2.118 + $adjust]
     set y_end [expr $d - $x_start]
-    $p create oval $x_start $x_start $y_end $y_end -outline grey90 -width 1 -tags disk
+    $p create oval $x_start $x_start $y_end $y_end -outline $color_light -width 1 -tags disk
+}
+
+proc fisheye(parallels_show) {} {
+    if {![winfo exists .fisheye]} return
+
+    set cmdll ".fisheye.cmd.ll"
+
+    build_LabelEntryColumns $cmdll le2 \
+     {text "" "Parallels"} \
+     {dentry "" {parallels_angle}} \
+	{text "" "degrees"}
+
+    bind $cmdll.le2.c1.0 <Return> equator(update_angle)
+    bind $cmdll.le2.c1.0 <Tab> equator(update_angle)
+
+    pack $cmdll
+}
+
+proc fisheye(parallels_hide) {} {
+    if {![winfo exists .fisheye]} return
+
+       destroy .fisheye.cmd.ll.le2
 }
 
 proc fisheye(delete) {} {
