@@ -19,7 +19,7 @@
 ######################################################
 #
 # textfile.tcl
-# $Id: helpfile.tcl,v 1.22 2017/01/02 06:11:33 lloydwood Exp $
+# $Id: helpfile.tcl 168 2020-04-28 03:15:28Z lloydwood $
 
 proc helpfile(build) {helpfile} {
     global helpfile_name helpfile_text
@@ -72,7 +72,7 @@ proc helpfile(load) {helpfile} {
     if {[string compare "" $helpfile] == 0} {
 	# special case starting SaVi without a constellation loaded.
 	set file_text "\nThis is a simple low-Earth-orbiting equatorial example satellite."
-   } elseif {![file exists $helpfile]} {
+   } elseif {[file exists $helpfile] == 0} {
 	set file_text "\nThe $helpfile textfile is not available to SaVi.\n\n$helpfile may have been removed or moved. SaVi may have been packaged incorrectly by a third party.\n\nPlease install the full version of SaVi, which includes $helpfile, from: http://savi.sf.net/"
     } else {
 	set f [open "$helpfile" r]
