@@ -20,7 +20,7 @@
 #
 # main.tcl
 #
-# $Id: main.tcl,v 1.166 2017/01/02 11:30:45 lloydwood Exp $
+# $Id: main.tcl 209 2023-04-30 10:29:46Z lloydwood $
 
 proc main(build) {} {
     global main_name COLOR FONT TITLE geomview_module last_filename PLATFORM
@@ -61,7 +61,9 @@ proc main(build) {} {
 	    {"Load more satellites..." "load(build)"} \
 	    {"Save satellites as Tcl script..." "save(build)" "S"} \
 	    {} \
-            {"Load new constellation TLEs from web..." "load_url_tle(build)"} \
+            {"Download new constellation TLEs..." "load_url_tle(build)"} \
+	    {} \
+	    {"Save satellites for plot script..." main(save_plot)} \
 	    {} \
 	    {"Quit" "main(exit)" "Q"}
 	build_Menu $main_name.mbar.b2 \
@@ -80,7 +82,9 @@ proc main(build) {} {
 	    {"Load satellites..." "load(build)"} \
 	    {"Save satellites as Tcl script..." "save(build)" "S"} \
             {} \
-            {"Load new constellation TLEs from web..." "load_url_tle(build)"} \
+            {"Download constellation TLEs..." "load_url_tle(build)"} \
+	    {} \
+	    {"Save satellites for plot script..." main(save_plot)} \
 	    {} \
 	    {"Save Geomview camera screenshots..." "no_frames(build)"} \
 	    {"Save Geomview print rendering..." "snapshot(build)"} \
@@ -163,6 +167,27 @@ proc main(build) {} {
 
 }
 
+proc main(save_plot) {} {
+    global user_file_dir
+
+    set types {
+        {"ns-2 dump file" {.dump} } \
+    }
+
+    set filename [tk_getSaveFile -initialdir "$user_file_dir" -filetypes $types \
+                  -parent .main -title "SaVi: save for satellite plot scripts"]
+
+    if {"$filename" == ""} return
+
+    satellites COVERAGE_SAVE_PLOT "$filename"
+
+    if {[winfo exists .coverage]} {
+	coverage(save_plot) "$filename"
+    } else {
+        puts stderr "\nSaVi: can't save background map without a Coverage window."
+    }
+}
+
 proc main(start_satellites) {} {
     global first_filename last_filename source_comments comments_text comments_file details_source
 
@@ -193,59 +218,150 @@ proc main(constellations_menu) {submenu} {
 
     build_Menu $submenu \
 	{"Empty space..." "empty(build)" "M"} \
-	{"Ballard rosette..." "rosette(build)"} \
-	{"Crude star..." "star(build)"} \
 	{} \
-	{"Clarke geostationary" "main(constellation) clarke.tcl"} \
-	{"Draim tetrahedral" "main(constellation) draim-4.tcl"} \
-	{"Molnya elliptical" "main(constellation) molnya.tcl"} \
-	{"Tundra elliptical" "main(constellation) tundra.tcl"} \
-	{"Quasi-geostationary" "main(constellation) quasi-geo.tcl"} \
-	{} \
-	{"Globalstar" "main(constellation) globalstar.tcl"} \
-	{"Iridium" "main(constellation) iridium-66.tcl"} \
-	{"Orbcomm" "main(constellation) orbcomm.tcl"} \
-	{"Sirius Radio elliptical" "main(constellation) sirius-radio.tcl"} \
-	{"DMC disaster monitoring" "main(constellation) dmc.tcl"} \
-	{"RapidEye" "main(constellation) rapideye.tcl"} \
-	{} \
-	{"GPS" "main(constellation) gps.tcl"} \
-	{"Glonass" "main(constellation) glonass.tcl"} \
-	{"Galileo" "main(constellation) galileo.tcl"} \
-	{} \
-        {"O3b Networks" "main(constellation) o3b-networks.tcl"} \
-        {"Orblink" "main(constellation) orblink.tcl"} \
-        {"LEq0" "main(constellation) leqo.tcl"} \
+	{"SUBMENU" "geosync" "Geosynchronous" } \
+        {"SUBMENU" "ellip" "Elliptical"} \
+	{"SUBMENU" "eq" "Equatorial"} \
+	{"SUBMENU" "meo" "Medium Earth Orbit (MEO)"} \
         {} \
-        {"ViaSat NGSO" "main(constellation) viasat-ngso.tcl"} \
-	{"O3b full global coverage" "main(constellation) o3b-networks-full.tcl"} \
-	{"LeoSat (108)" "main(constellation) leosat.tcl"} \
-	{"OneWeb (720)" "main(constellation) oneweb.tcl"} \
+	{"SUBMENU" "navigation" "Navigation (MEO)" } \
+	{"SUBMENU" "voice" "Voice"} \
+	{"SUBMENU" "sensing" "Remote sensing"} \
+	{"SUBMENU" "messaging" "Messaging"} \
 	{} \
-	{"COMMstellation (78)" "main(constellation) commstellation-78.tcl"} \
-	{"NeLS (120)" "main(constellation) nels.tcl"} \
-	{"Celestri (63)" "main(constellation) celestri.tcl"} \
-	{"SkyBridge (64)" "main(constellation) skybridge-64.tcl"} \
-	{"SkyBridge (80)" "main(constellation) skybridge-80.tcl"} \
-        {"Teledesic (288)" "main(constellation) teledesic-288.tcl"} \
-        {"Teledesic (840)" "main(constellation) teledesic-840.tcl"} \
+	{"SUBMENU" "mega" "2010s 'megaconstellations'"} \
+	{"SUBMENU" "broad" "1990s large broadband proposals"} \
+	{"SUBMENU" "other" "Other proposed designs"} \
 	{} \
-	{"Aries" "main(constellation) aries.tcl"} \
-	{"Boeing Higgins patent" "main(constellation) us-patent-6726152-boeing.tcl"} \
-	{"Deligo" "main(constellation) deligo.tcl"} \
-	{"@contact" "main(constellation) atcontact.tcl"} \
-	{"Ellipso" "main(constellation) ellipso.tcl"} \
-	{"GS2" "main(constellation) gs2.tcl"} \
-	{"ICO" "main(constellation) ico.tcl"} \
-	{"Macrocell" "main(constellation) macrocell.tcl"} \
-	{"Millimeter elliptical" "main(constellation) mm.tcl"} \
-	{"NUONCE" "main(constellation) nuonce.tcl"} \
-	{"Odyssey" "main(constellation) odyssey.tcl"} \
-	{"Spaceway NGSO" "main(constellation) spaceway-ngso.tcl"} \
-	{} \
-	{"Geosynchronous belt (TLE)" "main(constellation) geo.tle"} \
-	{"Brightest LEO craft (TLE)" "main(constellation) visual.tle"}
+        {"Ballard rosette..." "rosette(build)"} \
+         {"Crude star..." "star(build)"} \
+        {} \
+	{"SUBMENU" "tle" "Sample two-line elsets (TLE)"} \
 
+    # build submenus
+    build_Menu $submenu.geosync \
+       {"Clarke geostationary" "main(constellation) clarke.tcl"} \
+       {} \
+       {"Quasi-geostationary" "main(constellation) quasi-geo.tcl"} \
+       {"Karousel" "main(constellation) karousel.tcl"} \
+       {} \
+       {"Molnya elliptical" "main(constellation) molnya.tcl"} \
+       {"Tundra elliptical" "main(constellation) tundra.tcl"} \
+       {"Sirius Radio" "main(constellation) sirius-radio.tcl"} \
+       {} \
+       {"Draim tetrahedral" "main(constellation) draim-4.tcl"} \
+       {"Singh 24-hour tetrahedral" "main(constellation) singh-24hr.tcl"} \
+       {"Singh 48-hour tetrahedral" "main(constellation) singh-48hr.tcl"}
+
+
+    build_Menu $submenu.navigation \
+       {"Global Positioning System (GPS)" "main(constellation) gps.tcl"} \
+       {"Glonass" "main(constellation) glonass.tcl"} \
+       {"Galileo" "main(constellation) galileo.tcl"} \
+
+    build_Menu $submenu.mega \
+       {"SpaceX Starlink first shell (1,584)" "main(constellation) spacex-starlink-inner.tcl"} \
+       {"OneWeb (720)" "main(constellation) oneweb.tcl"} \
+       {} \
+       {"SUBMENU" "kuiper" "Amazon Project Kuiper"} \
+       {"SUBMENU" "telesat" "Telesat Lightspeed"} \
+       {"ViaSat (LEO)" "main(constellation) viasat-leo.tcl"} \
+       {} \
+       {"LeoSat (78)" "main(constellation) leosat.tcl"}
+
+
+    build_Menu $submenu.mega.kuiper \
+      {"Amazon Project Kuiper first shell (1,156)" "main(constellation) amazon-project-kuiper-first.tcl"} \
+      {"Amazon Project Kuiper second shell (784)" "main(constellation) amazon-project-kuiper-second.tcl"} \
+      {"Amazon Project Kuiper third shell (1,296)" "main(constellation) amazon-project-kuiper-third.tcl"} \
+      {} \
+      {"all of Amazon Project Kuiper" "main(constellation) amazon-project-kuiper-all.tcl"}
+
+    build_Menu $submenu.mega.telesat \
+      {"Telesat polar (72)" "main(constellation) telesat-polar.tcl"} \
+      {"Telesat inclined (45)" "main(constellation) telesat-inclined.tcl"} \
+      {} \
+      {"all of Telesat" "main(constellation) telesat-all.tcl"}
+
+    build_Menu $submenu.broad \
+       {"SUBMENU" "teledesic" "Teledesic"} \
+       {"SUBMENU" "skybridge" "Skybridge"} \
+       {"Celestri (63)" "main(constellation) celestri.tcl"} \
+       {"COMMstellation (78)" "main(constellation) commstellation-78.tcl"} \
+       {"NeLS (120)" "main(constellation) nels.tcl"} \
+	
+    build_Menu $submenu.broad.teledesic \
+      {"1997 reduced Boeing design (288)" "main(constellation) teledesic-288.tcl"} \
+      {"1994 original design (840)" "main(constellation) teledesic-840.tcl"}   
+
+    build_Menu $submenu.broad.skybridge \
+      {"1998 redesign (80)" "main(constellation) skybridge-80.tcl"} \
+      {"1997 original design (64)" "main(constellation) skybridge-64.tcl"}
+ 
+    build_Menu $submenu.ellip \
+       {"Molnya" "main(constellation) molnya.tcl"} \
+       {"Tundra" "main(constellation) tundra.tcl"} \
+       {"Sirius Radio" "main(constellation) sirius-radio.tcl"} \
+       {} \
+       {"Draim tetrahedral" "main(constellation) draim-4.tcl"} \
+       {"Ellipso (for Concordia)" "main(constellation) ellipso.tcl"} \
+       {"Karousel" "main(constellation) karousel.tcl"} \
+       {"Millimeter" "main(constellation) mm.tcl"}
+
+    build_Menu $submenu.eq \
+       {"Clarke geostationary" "main(constellation) clarke.tcl"} \
+       {"O3b Networks" "main(constellation) o3b-networks.tcl"} \
+       {} \
+       {"Laser Light (HALO)" "main(constellation) laser-light-halo.tcl"} \
+       {"Ellipso (for Borealis)" "main(constellation) ellipso.tcl"} \
+       {"Orblink" "main(constellation) orblink.tcl"} \
+       {"LEq0" "main(constellation) leqo.tcl"}
+
+    build_Menu $submenu.meo \
+       {"O3b Networks" "main(constellation) o3b-networks.tcl"} \
+       {} \
+       {"O3b full global coverage" "main(constellation) o3b-networks-full.tcl"} \
+       {"Audacy" "main(constellation) audacy.tcl"} \
+       {"Laser Light (HALO)" "main(constellation) laser-light-halo.tcl"} \
+       {} \
+       {"ViaSat NGSO" "main(constellation) viasat-ngso.tcl"} \
+       {"Spaceway NGSO" "main(constellation) spaceway-ngso.tcl"} \
+       {"Orblink" "main(constellation) orblink.tcl"} \
+       {} \
+       {"Ellipso" "main(constellation) ellipso.tcl"} \
+       {"ICO" "main(constellation) ico.tcl"} \
+       {"Odyssey" "main(constellation) odyssey.tcl"} \
+
+    build_Menu $submenu.voice \
+       {"Globalstar" "main(constellation) globalstar.tcl"} \
+       {"Iridium" "main(constellation) iridium-66.tcl"} \
+       {} \
+       {"Ellipso" "main(constellation) ellipso.tcl"} \
+       {"ICO" "main(constellation) ico.tcl"} \
+       {"Odyssey" "main(constellation) odyssey.tcl"} \
+
+    build_Menu $submenu.sensing \
+       {"RADARSAT" "main(constellation) radarsat-rcm.tcl"} \
+       {"DMC disaster monitoring" "main(constellation) dmc.tcl"} \
+       {"RapidEye" "main(constellation) rapideye.tcl"} \
+       {} \
+       {"Theia" "main(constellation) theia.tcl"}
+
+    build_Menu $submenu.messaging \
+       {"Orbcomm" "main(constellation) orbcomm.tcl"}
+
+    build_Menu $submenu.other \
+       {"Aries" "main(constellation) aries.tcl"} \
+       {"Boeing Higgins patent" "main(constellation) us-patent-6726152-boeing.tcl"} \
+       {"Deligo" "main(constellation) deligo.tcl"} \
+       {"@contact" "main(constellation) atcontact.tcl"} \
+       {"GS2" "main(constellation) gs2.tcl"} \
+       {"Macrocell" "main(constellation) macrocell.tcl"} \
+       {"NUONCE" "main(constellation) nuonce.tcl"}
+
+build_Menu $submenu.tle \
+        {"Geosynchronous belt (TLE)" "main(constellation) geo.tle"} \
+        {"Brightest LEO craft (TLE)" "main(constellation) visual.tle"}
 }
 
 proc main(rendering_menu) {submenu} {
@@ -255,11 +371,7 @@ proc main(rendering_menu) {submenu} {
 	build_options_menu $submenu \
 	    {"Real-time mode" realtime_flag} \
 	    {} \
-	    {"Mark satellite positions" satellites_flag} \
-	    {"Sphere markers" sphere_sat_flag} \
-	    {"Box markers" box_sat_flag} \
-	    {"Planes markers" planes_sat_flag} \
-            {"Satellite markers" fancy_sat_flag} \
+	    {"SUBMENU" "markers" "Satellite markers"} \
 	    {} \
 	    {"Show satellite orbits" orbits_flag} \
 	    {"Show footprints" footprints_flag} \
@@ -273,8 +385,17 @@ proc main(rendering_menu) {submenu} {
 	    {"Show central body" earth_flag} \
 	    {"Use simple Earth map" simple_earth_flag} \
 	    {"Use detailed Earth map" fancy_earth_flag} \
+	    {"Use generated coverage map" geomview_dynamic_texture_flag} \
 	    {} \
     	    {"Animate in Geomview" geomview_flag}
+
+	build_options_menu $submenu.markers \
+		    {"Sphere markers" sphere_sat_flag} \
+		    {"Box markers" box_sat_flag} \
+		    {"Planes markers" planes_sat_flag} \
+		    {"Satellite markers" fancy_sat_flag} \
+		    {} \
+		    {"Mark satellite positions" satellites_flag}
     } else {
 	build_options_menu $submenu \
 	    {"Real-time mode" realtime_flag}
@@ -624,7 +745,7 @@ proc main(delete) {} {
 }
 
 proc main(delete_all) {} {
-    global project_tracks_flag last_filename main_name details_source source_comments
+    global project_tracks_flag last_filename details_source source_comments
 
     set project_tracks_flag 0
     satellites DELETE_ALL
@@ -647,7 +768,6 @@ proc main(delete_all) {} {
 
 
 proc main(constellation) {filename} {
-    global geomview_module last_filename PI params
 
     # We could choose not to delete all satellites when loading
     # in an additional constellation, but since mask angle is
@@ -720,7 +840,7 @@ proc main(source_file) {filename} {
 }
 
 proc main(load_file) {filename} {
-    global geomview_module last_filename no_access_flag
+    global geomview_module last_filename
 
 
     if {![file exists "$filename"]} {
