@@ -6,7 +6,7 @@
 #          Robert Thurman.
 #
 #  Copyright (c) 1997 by The Geometry Center.
-#  Also Copyright (c) 2016 by Lloyd Wood.
+#  Also Copyright (c) 2017 by Lloyd Wood.
 #
 #  This file is part of SaVi.  SaVi is free software;
 #  you can redistribute it and/or modify it only under
@@ -20,7 +20,7 @@
 #
 # no_frames.tcl
 #
-# $Id: no_frames.tcl,v 1.22 2016/03/29 03:43:13 lloydwood Exp $
+# $Id: no_frames.tcl 8 2019-01-24 04:33:00Z lloydwood $
 
 proc no_frames(build) {} {
     if {[eval window(raise) no_frames]} return
@@ -44,6 +44,7 @@ proc no_frames(build) {} {
 }
 
 proc no_frames(save) v {
+    global user_file_dir
 
     if {$v < 0} return
 
@@ -53,22 +54,26 @@ proc no_frames(save) v {
         {"SaVi snapshot frames"  {.ppm} }
     }
 
-    set filename [tk_getSaveFile -filetypes $types \
+    set filename [tk_getSaveFile -initialdir "$user_file_dir" -filetypes $types \
 	          -title "SaVi: save frames to folder" ]
 
     if {"$filename" == ""} return
 
+    set length [string length "$filename"]
+
+    if {[string_ends "$filename" ".ppm"]} {
+        set filename [string range "$filename" 0 [expr $length - 5]]
+    }
+
     if {$v == 1} {
 	geomview(puts) "(snapshot focus $filename.ppm)"
     } else {
-	set i $v
-
 	for {set j 0} {$j < $v} {incr j} {
+            set n  [format "%07d" $j]
 	    geomview(wait)
-	    geomview(puts) "(snapshot focus $filename$i.ppm)"
+	    geomview(puts) "(snapshot focus $filename$n.ppm)"
 	    main(forw_step)
 	    geomview(wait)
-	    incr i
 	}
     }
 }
