@@ -20,10 +20,12 @@
 #
 # params.tcl
 #
-# $Id: params.tcl,v 1.18 2017/01/02 06:11:33 lloydwood Exp $
+# $Id: params.tcl 198 2023-04-16 08:54:04Z lloydwood $
 
 
 proc params(build) {} {
+    global PI params tparams rotation_period
+
     if {[eval window(raise) params]} return
 
     set name [build_Toplevel params]
@@ -36,9 +38,13 @@ proc params(build) {} {
 
     set cmda [build_StdFrame $cmd a]
 
+    # params(orbital_period) is around the Sun.
+    # We show length of day as it is easier to understand.
+    set rotation_period [expr 2.0*$PI/$params(Omega)]
+
     build_LabelEntryColumns $cmda le0 \
-	    {text " " {"Radius (km)" "Rotation rate (rad/s)" } } \
-	    {dentry "Central body" {tparams(Radius) tparams(Omega) } }
+	    {text " " {"Radius (km)" "Rotational period (s)" "Tilt (degrees)"} } \
+	    {dentry "Central body" {tparams(Radius) rotation_period tparams(tilt)} }
 
     pack $cmda -side left -expand 1
 
@@ -71,24 +77,33 @@ proc params(dismiss) {} {
 }
 
 proc params(apply) {} {
-    global params tparams
-
+    global PI params tparams rotation_period
+    
     set inds [array names tparams]
     foreach ind $inds {
-	set params($ind) $tparams($ind)
+        set params($ind) $tparams($ind)
     }
 
+    # Omega is definitive, we compute from display
+    set params(Omega) [expr 2.0*$PI/$rotation_period]
+
     # now update other panels if necessary
     edit(update)
 }
 
 proc params(cancel) {} {
-    global params tparams
+    global PI params tparams rotation_period
 
+    # when inheriting all params, without messing for the user interface,
+    # this mapping code is useful.
+    
     set inds [array names tparams]
     foreach ind $inds {
-	set tparams($ind) $params($ind)
+        set tparams($ind) $params($ind)
     }
+
+    # Omega is definitive, we return to display
+    set rotation_period [expr 2.0*$PI/$params(Omega) ]
 }
 
 proc params(reset) {} {
