@@ -20,7 +20,7 @@
 #
 # save.tcl
 #
-# $Id: save.tcl,v 1.31 2017/07/02 11:07:11 lloydwood Exp $
+# $Id: save.tcl 132 2020-01-03 10:22:37Z lloydwood $
 
 proc save(build) {} {
     global last_filename user_file_dir
@@ -62,21 +62,15 @@ proc save(build) {} {
 
     # put a wrapper around satellite creation
     puts $f "satellites GV_BEGIN"
-
+    
     # write satellites
     # skip 0, as that's sunlight
     for {set i 1} {$i <= $n} {incr i} {
+	set name [satellites GET_NAME $i]
 	set noe [satellites GET $i]
-	puts -nonewline $f "satellites LOAD "
-	puts $f $noe
-    }
-
-    puts $f "\# satellite names, if any, follow."
-    for {set i 1} {$i <= $n} {incr i} {
-	set noe [satellites GET_NAME $i]
-	if {$noe != ""} {
-	    puts $f "satellites NAME $i {$noe}"
-	}
+	# we strip elements of extraneous settings
+	set noe [string range $noe 0 70]
+	puts $f "satellites LOAD $noe \"$name\""
     }
 
     # close file
@@ -98,3 +92,16 @@ proc save(extension) {filename extension} {
 	return "$filename"
     }
 }
+
+proc save(gzip_file) {filename} {
+
+    set gzip gzip
+
+    if {[catch {eval exec $gzip -9 "$filename"}]} {
+        puts stderr "\nSaVi: failed to compress file with $gzip."
+        return FALSE
+    }
+    puts stderr "\nSaVi: saved $gzip-compressed file to $filename.gz"
+    return TRUE
+}
+
