@@ -20,7 +20,7 @@
 #
 # sunlight.tcl
 #
-# $Id: sunlight.tcl,v 1.14 2017/01/02 06:11:33 lloydwood Exp $
+# $Id: sunlight.tcl 199 2023-04-16 08:59:33Z lloydwood $
 
 
 # Sunlight on Earth
@@ -34,10 +34,9 @@
 
 proc sunlight(create) {} {
 
-set PI 3.14159
+global PI params
 
-# valid for Earth's gravitational field.
-set MU 398601.2
+set MU $params(Mu)
 
 # set up orbital elements
 
@@ -79,12 +78,12 @@ set MU 398601.2
 
 
 # set period of a year.
-set T_per [expr 360.25 * 24 * 60 * 60]
+set T_per $params(orbital_period)
 set a1 [expr $T_per * sqrt($MU) / ( 2 * $PI) ]
 set a [expr pow($a1,0.666666667)]
 
 # Inclination is angle between planes of equator and ecliptic.
-set inc 23.45
+set inc $params(tilt)
 
 # Eccentricity of 0 is an approximation --
 # if we set this to anything other than zero, we'll
