@@ -20,10 +20,10 @@
 #
 # utils.tcl
 #
-# $Id: utils.tcl,v 1.61 2017/01/02 06:11:33 lloydwood Exp $
+# $Id: utils.tcl 50 2019-08-01 11:47:29Z lloydwood $
 
 proc window(raise) {window} {
-    if {[winfo exists .$window]} {
+    if [winfo exists .$window] {
 	wm deiconify .$window
 	raise .$window
 	return 1
@@ -194,7 +194,7 @@ proc build_Menubar {parent name helpmenu args} {
     }
 
     # menubars are not currently rebuilt!
-    if {[winfo exists $mbarname.b0]} {
+    if [winfo exists $mbarname.b0] {
 	puts stderr "\nbuild_Menubar: NOT rebuilding $mbarname"
 	return
     }
@@ -305,20 +305,28 @@ proc build_Menu {parent args} {
     # add commands to menu
     foreach arg $args {
 	if {[llength $arg] > 1} {
-	    set command [lindex $arg 1]
-	    set key [lindex $arg 2]
-	    if {(!$disable_mac)&&([string length $key] > 0)} {
-		set accelerator $modifier_indicator-[lindex $arg 2]
-                set upperkey [string toupper $key]
-                set lowerkey [string tolower $key]
+	    
+	    set name [lindex $arg 0]
+	    if {[string compare $name "SUBMENU"] == 0} {
+		set submenu_id [lindex $arg 1]
+		set submenu_name [lindex $arg 2]
+	        $mname add cascade -menu $mname.$submenu_id -label $submenu_name
+            } else {
+		set command [lindex $arg 1]
+	        set key [lindex $arg 2]
+	        if {(!$disable_mac)&&([string length $key] > 0)} {
+		    set accelerator $modifier_indicator-[lindex $arg 2]
+                    set upperkey [string toupper $key]
+                    set lowerkey [string tolower $key]
 
-                # We have to bind to .main, .coverage etc. Just . doesn't work
-                bind $parent_window <$modifier-$upperkey> $command
-                bind $parent_window <$modifier-$lowerkey> $command
-	    } else {
-	        set accelerator ""
+                    # We have to bind to .main, .coverage etc. Just . doesn't work
+                   bind $parent_window <$modifier-$upperkey> $command
+                   bind $parent_window <$modifier-$lowerkey> $command
+	        } else {
+	            set accelerator ""
+	        }
+	        $mname add command -label $name -command $command -accelerator $accelerator
 	    }
-	    $mname add command -label [lindex $arg 0] -command $command -accelerator $accelerator
 	} else {
 	    $mname add separator
 	}
@@ -342,15 +350,16 @@ proc build_Buttonbar {parent name args} {
     set i 0
     foreach arg $args {
 	if {[llength $arg] > 1} {
-	    if { [winfo exists $bbarname.b$i] == 0} {
+	    if {![winfo exists $bbarname.b$i]} {
 		button $bbarname.b$i -font $FONT(button)
 		pack $bbarname.b$i -side left -padx 2 -pady 2
 	    }
 	    set name [lindex $arg 0]
 	    if {([string compare $name "Cancel"] == 0) ||
+		([string compare $name "Close"] == 0) ||
 		([string compare $name "Restart"] == 0) ||
 	        ([string compare $name "Dismiss"] == 0) ||
-		([string compare $name "Dismiss window"] == 0)} {
+       		([string compare $name "Dismiss window"] == 0)}	{
 		# pad to avoid drawing under grow box (Mac OS X)
 		pack $bbarname.b$i -side right -padx 15
 	    }
@@ -358,7 +367,7 @@ proc build_Buttonbar {parent name args} {
 		-command [lindex $arg 1]
 	    incr i
 	}
-	while { [winfo exists $bbarname.b$i] == 1} {
+	while [winfo exists $bbarname.b$i] {
 	    destroy $bbarname.b$i
 	    incr i
 	}
@@ -388,7 +397,7 @@ proc build_DismissButtonbar {parent name dismiss args} {
     set i 0
     foreach arg $args {
 	if {[llength $arg] > 1} {
-	    if { [winfo exists $bbarname.b$i] == 0} {
+	    if {![winfo exists $bbarname.b$i]} {
 		button $bbarname.b$i -font $FONT(button)
 		pack $bbarname.b$i -side left -padx 2 -pady 2
 	    }
@@ -396,14 +405,14 @@ proc build_DismissButtonbar {parent name dismiss args} {
 		-command [lindex $arg 1]
 	    incr i
 	}
-	while { [winfo exists $bbarname.b$i] == 1} {
+	while [winfo exists $bbarname.b$i] {
 	    destroy $bbarname.b$i
 	    incr i
 	}
     }
 
     # add dismiss button on right side
-    if {[winfo exists $bbarname.dismiss] == 0} {
+    if {![winfo exists $bbarname.dismiss]} {
 	button $bbarname.dismiss -font $FONT(button)
 	# pad to avoid drawing under grow box (Mac OS X)
 	pack $bbarname.dismiss -in $bbarname -side right -anchor e \
@@ -436,7 +445,7 @@ proc build_Optionslist {parent name args} {
     set i 0
     foreach arg $args {
 	if {[llength $arg] > 1} {
-	    if { [winfo exists $olistname.b$i] == 0} {
+	    if {![winfo exists $olistname.b$i]} {
 		checkbutton $olistname.b$i -anchor w -font $FONT(label)
 		pack $olistname.b$i -side top -fill x -padx 0.1c -pady 0.1c
 	    }
@@ -445,7 +454,7 @@ proc build_Optionslist {parent name args} {
 		-variable [lindex $arg 1]
 	    incr i
 	}
-	while {[winfo exists $olistname.b$i] == 1} {
+	while [winfo exists $olistname.b$i] {
 	    destroy $olistname.b$i
 	    incr i
 	}
@@ -475,7 +484,7 @@ proc build_HOptionslist {parent name cmd args} {
     set i 0
     foreach arg $args {
 	if {[llength $arg] > 1} {
-	    if { [winfo exists $olistname.b$i] == 0} {
+	    if {![winfo exists $olistname.b$i]} {
 		checkbutton $olistname.b$i -anchor w -font $FONT(label) -command $cmd
 		pack $olistname.b$i -side left -padx 0.1c -pady 0.1c
 	    }
@@ -483,7 +492,7 @@ proc build_HOptionslist {parent name cmd args} {
 		-variable [lindex $arg 1]
 	    incr i
 	}
-	while {[winfo exists $olistname.b$i] == 1} {
+	while [winfo exists $olistname.b$i] {
 	    destroy $olistname.b$i
 	    incr i
 	}
@@ -505,7 +514,7 @@ proc build_Scrollingtext {parent name width height} {
     set stext [ build_StdFrame $parent $name ]
 
     # add text widget
-    if {[winfo exists $stext.text] == 0} {
+    if {![winfo exists $stext.text]} {
 	text $stext.text -relief sunken -bd 2 \
 	    -yscrollcommand "$stext.scroll set" \
 	    -bg $COLOR(entry) -font $FONT(label) \
@@ -514,7 +523,7 @@ proc build_Scrollingtext {parent name width height} {
 	pack $stext.text -side left -fill both -expand 1
     }
     # add scrollbar
-    if {[winfo exists $stext.scroll] == 0} {
+    if {![winfo exists $stext.scroll]} {
        scrollbar $stext.scroll -command "$stext.text yview"
        pack $stext.scroll -side right -fill y
     }
@@ -531,7 +540,7 @@ proc build_Text {parent name width height} {
     global COLOR FONT
 
     # build text widget
-    if {[winfo exists $parent.text] == 0} {
+    if {![winfo exists $parent.text]} {
 	text $parent.text -relief sunken -bd 2 \
 	    -bg $COLOR(entry) -font $FONT(label) \
 	    -width 1 -height 1
@@ -574,7 +583,7 @@ proc build_IPopupMenu { parent name label ivar command items } {
 
     # if no items then do not create menubar!
     if {![llength $items]} {
-	if {[winfo exists $wname.mb]} {destroy $wname.mb}
+	if [winfo exists $wname.mb] {destroy $wname.mb}
 	pack $wname.label -side left -padx 0.1c
 	pack $wname -fill x -pady 0.1c
 	return $wname
@@ -591,7 +600,7 @@ proc build_IPopupMenu { parent name label ivar command items } {
     $wname.mb configure -text "[lindex $items $iv]" -width $w
 
     # make menu
-    if {[winfo exists $wname.mb.m]} {
+    if [winfo exists $wname.mb.m] {
 	destroy $wname.mb.m
     }
     menu $wname.mb.m -font $FONT(label)
@@ -631,7 +640,7 @@ proc build_PopupMenu { parent name label ivar command items } {
 
     # if no items then do not create menubar!
     if {![llength $items]} {
-	if {[winfo exists $wname.mb]} {destroy $wname.mb}
+	if [winfo exists $wname.mb] {destroy $wname.mb}
 	pack $wname.label -side left -padx 0.1c
 	pack $wname -fill x -pady 0.1c
 	return $wname
@@ -648,7 +657,7 @@ proc build_PopupMenu { parent name label ivar command items } {
     $wname.mb configure -text "[lindex $items $iv]" -width $w
 
     # make menu
-    if {[winfo exists $wname.mb.m]} {
+    if [winfo exists $wname.mb.m] {
 	destroy $wname.mb.m
     }
     menu $wname.mb.m -font $FONT(label)
@@ -773,19 +782,19 @@ proc build_LabelEntryColumns {parent name args } {
 	if {$valid_type} {
 	    # create column and header
 	    set obj $parent.$name.$_code
-	    if { ![winfo exists $obj] } {
+	    if {![winfo exists $obj]} {
 		frame $obj
 		pack $obj -fill x -side left
 		# -padx 2 -pady 1
 	    }
 	    if {[string length "$_head"]} {
-		if { ![winfo exists $obj.head] } {
+		if {![winfo exists $obj.head]} {
 		    label $obj.head -anchor n -font $FONT(label)
 		    pack $obj.head -side top -padx 2 -pady 1
 		}
 		$obj.head configure -text "$_head"
 	    } else {
-		if {[winfo exists $obj.head]} {
+		if [winfo exists $obj.head] {
 		    destroy $obj.head
 		}
 	    }
@@ -802,7 +811,7 @@ proc build_LabelEntryColumns {parent name args } {
 #		eval $col_tab
 		incr _n
 	    }
-	    while { [winfo exists $obj.$_n] } {
+	    while [winfo exists $obj.$_n] {
 		destroy $obj.$_n
 		incr _n
 	    }
@@ -811,7 +820,7 @@ proc build_LabelEntryColumns {parent name args } {
 	incr cn
     }
 
-    while { [winfo exists $parent.$name.c$cn] } {
+    while [winfo exists $parent.$name.c$cn] {
 	destroy $parent.$name.c$cn
 	incr cn
     }
@@ -836,7 +845,7 @@ proc build_Label {parent name message} {
     global FONT
 
     set fname [build_StdFrame $parent $name]
-    if {[winfo exists $fname.label]} {
+    if [winfo exists $fname.label] {
         $fname.label configure -text $message
     } else {
       label $fname.label -text $message -font $FONT(label)
@@ -864,7 +873,7 @@ proc build_options_menu {owner args} {
     }
 
     # create menu
-    if {[winfo exists $owner]} {
+    if [winfo exists $owner] {
 	destroy $owner
     }
     if {$buttons_menu == 1} {
@@ -875,9 +884,19 @@ proc build_options_menu {owner args} {
 
     # add commands to menu
     foreach arg $args {
-	if {[llength $arg] == 2} {
-	    $owner add checkbutton -label [lindex $arg 0] \
-		-variable [lindex $arg 1]
+	if {[llength $arg] > 1} {
+	    if {[llength $arg] == 2} {
+	        $owner add checkbutton -label [lindex $arg 0] \
+	            -variable [lindex $arg 1]
+	    }
+ 	    if {[llength $arg] == 3} {
+	        set name [lindex $arg 0]
+	        if {[string compare $name "SUBMENU"] == 0} {
+	            set submenu_id [lindex $arg 1]
+	            set submenu_name [lindex $arg 2]
+	            $owner add cascade -menu $owner.$submenu_id -label $submenu_name
+	        }
+	    }
 	} else {
 	    $owner add separator
 	}
